"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore


class QSignalSpy(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qsignalspy.html

    **Detailed Description**

    QSignalSpy can connect to any signal of any object and records its emission.
    QSignalSpy itself is a list of **QVariant**  lists. Each emission of the
    signal will append one item to the list, containing the arguments of the
    signal.

    The following example records all signal emissions for the `clicked()`
    signal of a **QCheckBox** :

    **QCheckBox**  *box = ...;
        **QSignalSpy**  spy(box,
    SIGNAL(clicked(bool)));

        // do something that triggers the signal
    box->animateClick();

        QCOMPARE(spy.count(), 1); // make sure the
    signal was emitted exactly one time
        **QList** <**QVariant** > arguments
    = spy.takeFirst(); // take the first signal
    QVERIFY(arguments.at(0).toBool() == true); // verify the first argument

    `spy.takeFirst()` returns the arguments for the first emitted signal, as a
    list of **QVariant**  objects. The `clicked()` signal has a single bool
    argument, which is stored as the first entry in the list of arguments.

    The example below catches a signal from a custom object:

    **QSignalSpy**  spy(myCustomObject, SIGNAL(mySignal(int,**QString**
    ,double)));

        myCustomObject->doSomething(); // trigger emission of
    the signal

        **QList** <**QVariant** > arguments = spy.takeFirst();
    QVERIFY(arguments.at(0).typeId() == **QMetaType** ::Int);
    QVERIFY(arguments.at(1).typeId() == **QMetaType** ::**QString** );
    QVERIFY(arguments.at(2).typeId() == **QMetaType** ::Double);

    **Note:** Non-standard data types need to be registered, using the
    **qRegisterMetaType** () function, before you can create a QSignalSpy. For
    example:

    **qRegisterMetaType** <SomeStruct>();
        **QSignalSpy**  spy(&model,
    SIGNAL(whatever(SomeStruct)));

    To retrieve the instance, you can use **qvariant_cast** :

    // get the first argument from the first received signal:
        SomeStruct
    result = qvariant_cast<SomeStruct>(spy.at(0).at(0));

    **Verifying Signal Emissions**

    The QSignalSpy class provides an elegant mechanism for capturing the list of
    signals emitted by an object. However, you should verify its validity after
    construction. The constructor does a number of sanity checks, such as
    verifying that the signal to be spied upon actually exists. To make the
    diagnosis of test failures easier, the results of these checks should be
    checked by calling `QVERIFY(spy.isValid())` before proceeding further with a
    test.

    **See also** **QVERIFY** ().
    """

    @typing.overload
    def __init__(self, signal: QtCore.pyqtBoundSignal) -> None:
        """
        https://doc.qt.io/qt-6/qsignalspy.html#QSignalSpy

        **QSignalSpy::QSignalSpy(const QObject * object , const char * signal
        )**

        Constructs a new QSignalSpy that listens for emissions of the **signal**
        from the **QObject**  **object**. If QSignalSpy is not able to listen
        for a valid signal (for example, because **object** is `nullptr` or
        **signal** does not denote a valid signal of **object** ), an
        explanatory warning message will be output using **qWarning** () and
        subsequent calls to `isValid()` will return false.

        Example:

        QSignalSpy spy(myPushButton, SIGNAL(clicked(bool)));
        """
        ...

    @typing.overload
    def __init__(self, obj: QtCore.QObject, signal: QtCore.QMetaMethod) -> None:
        """
        https://doc.qt.io/qt-6/qsignalspy.html#QSignalSpy-1

        **[since 5.4] template <typename PointerToMemberFunction>
        QSignalSpy::QSignalSpy(const QObject * object , PointerToMemberFunction
        signal )**

        Constructs a new QSignalSpy that listens for emissions of the **signal**
        from the **QObject**  **object**. If QSignalSpy is not able to listen
        for a valid signal (for example, because **object** is `nullptr` or
        **signal** does not denote a valid signal of **object** ), an
        explanatory warning message will be output using **qWarning** () and
        subsequent calls to `isValid()` will return false.

        Example:

        **QSignalSpy**  spy(myPushButton, &**QPushButton** ::clicked);

        This function was introduced in Qt 5.4.
        """
        ...

    def __delitem__(self, i: int) -> None:
        ...

    def __setitem__(self, i: int, value: typing.Iterable[typing.Any]) -> None:
        ...

    def __getitem__(self, i: int) -> typing.List[typing.Any]:
        ...

    def __len__(self) -> int:
        ...

    def wait(self, timeout: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qsignalspy.html#wait

        **[since 5.0] bool QSignalSpy::wait(int timeout = 5000)**

        Starts an event loop that runs until the given signal is received.
        Optionally the event loop can return earlier on a **timeout** (in
        milliseconds).

        Returns `true` if the signal was emitted at least once in **timeout**
        milliseconds, otherwise returns `false`.

        Example:

        QVERIFY(spy.wait(1000));

        This function was introduced in Qt 5.0.
        """
        ...

    def signal(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qsignalspy.html#signal

        **QByteArray QSignalSpy::signal() const**

        Returns the normalized signal the spy is currently listening to.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsignalspy.html#isValid

        **bool QSignalSpy::isValid() const**

        Returns `true` if the signal spy listens to a valid signal, otherwise
        false.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QJsonValue(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qjsonvalue.html

    **Detailed Description**

    A value in JSON can be one of 6 basic types:

    JSON is a format to store structured data. It has 6 basic data types:

    * bool **QJsonValue::Bool**
      * double **QJsonValue::Double**
      * string
    **QJsonValue::String**
      * array **QJsonValue::Array**
      * object
    **QJsonValue::Object**
      * null **QJsonValue::Null**

    A value can represent any of the above data types. In addition, QJsonValue
    has one special flag to represent undefined values. This can be queried with
    **isUndefined** ().

    The type of the value can be queried with **type** () or accessors like
    **isBool** (), **isString** (), and so on. Likewise, the value can be
    converted to the type stored in it using the **toBool** (), **toString** ()
    and so on.

    Values are strictly typed internally and contrary to **QVariant**  will not
    attempt to do any implicit type conversions. This implies that converting to
    a type that is not stored in the value will return a default constructed
    return value.

    **QJsonValueRef**

    **QJsonValueRef**  is a helper class for **QJsonArray**  and **QJsonObject**
    . When you get an object of type **QJsonValueRef** , you can use it as if it
    were a reference to a QJsonValue. If you assign to it, the assignment will
    apply to the element in the **QJsonArray**  or **QJsonObject**  from which
    you got the reference.

    The following methods return **QJsonValueRef** :

    * **QJsonArray** ::operator[](qsizetype i)
      * **QJsonObject**
    ::operator[](const **QString**  & key) const

    **See also** **JSON Support in Qt**  and **JSON Save Game Example** .
    """

    class Type(enum.Enum):
        Null: QJsonValue = ...
        Bool: QJsonValue = ...
        Double: QJsonValue = ...
        String: QJsonValue = ...
        Array: QJsonValue = ...
        Object: QJsonValue = ...
        Undefined: QJsonValue = ...

    @typing.overload
    def __init__(self, type: "QJsonValue.Type" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#QJsonValue

        **QJsonValue::QJsonValue(QJsonValue::Type type = Null)**

        Creates a QJsonValue of type **type**.

        The default is to create a Null value.
        """
        ...

    @typing.overload
    def __init__(
        self,
        other: typing.Union[
            "QJsonValue",
            "QJsonValue.Type",
            typing.Iterable["QJsonValue"],
            bool,
            int,
            float,
            None,
            str,
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#QJsonValue-1

        **QJsonValue::QJsonValue(bool b )**

        Creates a value of type Bool, with value **b**.
        """
        ...

    def __hash__(self) -> int:
        ...

    @typing.overload
    def __getitem__(self, i: int) -> "QJsonValue":
        ...

    @typing.overload
    def __getitem__(self, key: str) -> "QJsonValue":
        ...

    def swap(self, other: "QJsonValue") -> None:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#swap

        **[since 5.10] void QJsonValue::swap(QJsonValue & other )**

        Swaps the value **other** with this. This operation is very fast and
        never fails.

        This function was introduced in Qt 5.10.
        """
        ...

    @typing.overload
    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#toString

        **QString QJsonValue::toString() const**

        Converts the value to a **QString**  and returns it.

        If **type** () is not String, a null **QString**  will be returned.

        **See also** **QString::isNull** ().
        """
        ...

    @typing.overload
    def toString(self, defaultValue: str) -> str:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#toString-1

        **QString QJsonValue::toString(const QString & defaultValue ) const**

        Converts the value to a **QString**  and returns it.

        If **type** () is not String, the **defaultValue** will be returned.
        """
        ...

    @typing.overload
    def toObject(
        self,
    ) -> typing.Dict[
        str,
        typing.Union[
            "QJsonValue",
            "QJsonValue.Type",
            typing.Iterable["QJsonValue"],
            bool,
            int,
            float,
            None,
            str,
        ],
    ]:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#toObject

        **QJsonObject QJsonValue::toObject(const QJsonObject & defaultValue )
        const**

        Converts the value to an object and returns it.

        If **type** () is not Object, the **defaultValue** will be returned.
        """
        ...

    @typing.overload
    def toObject(
        self,
        defaultValue: typing.Dict[
            str,
            typing.Union[
                "QJsonValue",
                "QJsonValue.Type",
                typing.Iterable["QJsonValue"],
                bool,
                int,
                float,
                None,
                str,
            ],
        ],
    ) -> typing.Dict[
        str,
        typing.Union[
            "QJsonValue",
            "QJsonValue.Type",
            typing.Iterable["QJsonValue"],
            bool,
            int,
            float,
            None,
            str,
        ],
    ]:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#toObject-1

        **QJsonObject QJsonValue::toObject() const**

        This is an overloaded function.

        Converts the value to an object and returns it.

        If **type** () is not Object, the **QJsonObject** () will be returned.
        """
        ...

    @typing.overload
    def toArray(self) -> typing.List["QJsonValue"]:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#toArray

        **QJsonArray QJsonValue::toArray(const QJsonArray & defaultValue )
        const**

        Converts the value to an array and returns it.

        If **type** () is not Array, the **defaultValue** will be returned.
        """
        ...

    @typing.overload
    def toArray(
        self, defaultValue: typing.Iterable["QJsonValue"]
    ) -> typing.List["QJsonValue"]:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#toArray-1

        **QJsonArray QJsonValue::toArray() const**

        This is an overloaded function.

        Converts the value to an array and returns it.

        If **type** () is not Array, a **QJsonArray** () will be returned.
        """
        ...

    def toDouble(self, defaultValue: float = ...) -> float:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#toDouble

        **double QJsonValue::toDouble(double defaultValue = 0) const**

        Converts the value to a double and returns it.

        If **type** () is not Double, the **defaultValue** will be returned.
        """
        ...

    def toInteger(self, defaultValue: int = ...) -> int:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#toInteger

        **[since 6.0] qint64 QJsonValue::toInteger(qint64 defaultValue = 0)
        const**

        Converts the value to an integer and returns it.

        If **type** () is not Double or the value is not a whole number
        representable as qint64, the **defaultValue** will be returned.

        This function was introduced in Qt 6.0.
        """
        ...

    def toInt(self, defaultValue: int = ...) -> int:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#toInt

        **[since 5.2] int QJsonValue::toInt(int defaultValue = 0) const**

        Converts the value to an int and returns it.

        If **type** () is not Double or the value is not a whole number, the
        **defaultValue** will be returned.

        This function was introduced in Qt 5.2.
        """
        ...

    def toBool(self, defaultValue: bool = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#toBool

        **bool QJsonValue::toBool(bool defaultValue = false) const**

        Converts the value to a bool and returns it.

        If **type** () is not bool, the **defaultValue** will be returned.
        """
        ...

    def isUndefined(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#isUndefined

        **bool QJsonValue::isUndefined() const**

        Returns `true` if the value is undefined. This can happen in certain
        error cases as e.g. accessing a non existing key in a **QJsonObject** .
        """
        ...

    def isObject(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#isObject

        **bool QJsonValue::isObject() const**

        Returns `true` if the value contains an object.

        **See also** **toObject** ().
        """
        ...

    def isArray(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#isArray

        **bool QJsonValue::isArray() const**

        Returns `true` if the value contains an array.

        **See also** **toArray** ().
        """
        ...

    def isString(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#isString

        **bool QJsonValue::isString() const**

        Returns `true` if the value contains a string.

        **See also** **toString** ().
        """
        ...

    def isDouble(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#isDouble

        **bool QJsonValue::isDouble() const**

        Returns `true` if the value contains a double.

        **See also** **toDouble** ().
        """
        ...

    def isBool(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#isBool

        **bool QJsonValue::isBool() const**

        Returns `true` if the value contains a boolean.

        **See also** **toBool** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#isNull

        **bool QJsonValue::isNull() const**

        Returns `true` if the value is null.
        """
        ...

    def type(self) -> "QJsonValue.Type":
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#type

        **QJsonValue::Type QJsonValue::type() const**

        Returns the type of the value.

        **See also** **QJsonValue::Type** .
        """
        ...

    def toVariant(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#toVariant

        **QVariant QJsonValue::toVariant() const**

        Converts the value to a **QVariant** ().

        The **QJsonValue**  types will be converted as follows:

        ConstantDescription
        `Null`**QMetaType::Nullptr**
        `Bool`**QMetaType::Bool**
        `Double`**QMetaType::Double**  or
        **QMetaType::LongLong**
        `String`**QString**
        `Array`QVariantList
        `Object`QVariantMap
        `Undefined`**QVariant** ()

        **See also** **fromVariant** ().
        """
        ...

    @staticmethod
    def fromVariant(variant: typing.Any) -> "QJsonValue":
        """
        https://doc.qt.io/qt-6/qjsonvalue.html#fromVariant

        **[static] QJsonValue QJsonValue::fromVariant(const QVariant & variant
        )**

        Converts **variant** to a **QJsonValue**  and returns it.

        The conversion will convert **QVariant**  types as follows:

        Source typeDestination type

          * **QMetaType::Nullptr**
        **QJsonValue::Null**

          * **QMetaType::Bool**

        **QJsonValue::Bool**
        * **QMetaType::Int**
          * **QMetaType::UInt**
          *
        **QMetaType::LongLong**
          * **QMetaType::ULongLong**
          *
        **QMetaType::Float**
          * **QMetaType::Double**

        **QJsonValue::Double**
        * **QMetaType::QString**

        **QJsonValue::String**

          *
        **QMetaType::QStringList**
          * **QMetaType::QVariantList**
        **QJsonValue::Array**

          * **QMetaType::QVariantMap**
          *
        **QMetaType::QVariantHash**

        **QJsonValue::Object**

          *
        **QMetaType::QUrl**

        **QJsonValue::String** . The conversion will use
        **QUrl::toString** () with flag **QUrl::FullyEncoded** , so as to ensure
        maximum compatibility in parsing the URL

          * **QMetaType::QUuid**
        **QJsonValue::String** . Since Qt 5.11, the resulting string will not
        include braces

          * **QMetaType::QCborValue**

        Whichever type
        **QCborValue::toJsonValue** () returns.

          *
        **QMetaType::QCborArray**

        **QJsonValue::Array** . See
        **QCborValue::toJsonValue** () for conversion restrictions.

          *
        **QMetaType::QCborMap**

        QJsonValue::Map. See
        **QCborValue::toJsonValue** () for conversion restrictions and the
        "stringification" of map keys.

        **Loss of information and other types**

        **QVariant**  can carry more information than is representable in JSON.
        If the **QVariant**  is not one of the types above, the conversion is
        not guaranteed and is subject to change in future versions of Qt, as the
        UUID one did. Code should strive not to use any other types than those
        listed above.

        If **QVariant::isNull** () returns true, a null **QJsonValue**  is
        returned or inserted into the list or object, regardless of the type
        carried by **QVariant** . Note the behavior change in Qt 6.0 affecting
        **QVariant::isNull** () also affects this function.

        A floating point value that is either an infinity or NaN will be
        converted to a null JSON value. Since Qt 6.0, **QJsonValue**  can store
        the full precision of any 64-bit signed integer without loss, but in
        previous versions values outside the range of ±2^53 may lose precision.
        Unsigned 64-bit values greater than or equal to 2^63 will either lose
        precision or alias to negative values, so **QMetaType::ULongLong**
        should be avoided.

        For other types not listed above, a conversion to string will be
        attempted, usually but not always by calling **QVariant::toString** ().
        If the conversion fails the value is replaced by a null JSON value. Note
        that **QVariant::toString** () is also lossy for the majority of types.
        For example, if the passed **QVariant**  is representing raw byte array
        data, it is recommended to pre-encode it to **Base64**  (or another
        lossless encoding), otherwise a lossy conversion using
        **QString::fromUtf8** () will be used.

        Please note that the conversions via **QVariant::toString** () are
        subject to change at any time. Both **QVariant**  and **QJsonValue**
        may be extended in the future to support more types, which will result
        in a change in how this function performs conversions.

        **See also** **toVariant** () and **QCborValue::fromVariant** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtQuick import *
import enum


class QSGMaterialShader(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsgmaterialshader.html

    **Detailed Description**

    QSGMaterialShader represents a combination of vertex and fragment shaders,
    data that define the graphics pipeline state changes, and logic that updates
    graphics resources, such as uniform buffers and textures.

    **Note:** All classes with QSG prefix should be used solely on the scene
    graph's rendering thread. See **Scene Graph and Rendering**  for more
    information.

    The **QSGMaterial**  and QSGMaterialShader form a tight relationship. For
    one scene graph (including nested graphs), there is one unique
    QSGMaterialShader instance that encapsulates the shaders and other data the
    scene graph uses to render an object with that material. Each
    **QSGGeometryNode**  can have a unique **QSGMaterial**  that defines how the
    graphics pipeline must be configured while drawing the node. An instance of
    QSGMaterialShader is never created explicitly by the user, it will be
    created on demand by the scene graph through **QSGMaterial::createShader**
    (). The scene graph creates an instance of QSGMaterialShader by calling the
    **QSGMaterial::createShader** () method, ensuring that there is only one
    instance of each shader implementation.

    In Qt 5, QSGMaterialShader was tied to OpenGL. It was built directly on
    QOpenGLShaderProgram and had functions like `updateState()` that could issue
    arbitrary OpenGL commands. This is no longer the case in Qt 6.
    QSGMaterialShader is not strictly data-oriented, meaning it provides data
    (shaders and the desired pipeline state changes) together with logic that
    updates data in a uniform buffer. Graphics API access is not provided. This
    means that a QSGMaterialShader cannot make OpenGL, Vulkan, Metal, or Direct
    3D calls on its own. Together with the unified shader management, this
    allows a QSGMaterialShader to be written once, and be functional with any of
    the supported graphics APIs at run time.

    The shaders set by calling the protected **setShaderFileName** () function
    control what material does with the vertex data from the geometry, and how
    the fragments are shaded. A QSGMaterialShader will typically set a vertex
    and a fragment shader during construction. Changing the shaders afterwards
    may not lead to the desired effect and must be avoided.

    In Qt 6, the default approach is to ship `.qsb` files with the application,
    typically embedded via the resource system, and referenced when calling
    **setShaderFileName** (). The `.qsb` files are generated offline, or at
    latest at application build time, from Vulkan-style GLSL source code using
    the `qsb` tool from the Qt Shader Tools module.

    There are three virtuals that can be overridden. These provide the data, or
    the logic to generate the data, for uniform buffers, textures, and pipeline
    state changes.

    **updateUniformData** () is the function that is most commonly reimplemented
    in subclasses. This function is expected to update the contents of a
    **QByteArray**  that will then be exposed to the shaders as a uniform
    buffer. Any QSGMaterialShader that has a uniform block in its vertex or
    fragment shader must reimplement **updateUniformData** ().

    **updateSampledImage** () is relevant when the shader code samples textures.
    The function will be invoked for each sampler (or combined image sampler, in
    APIs where relevant), giving it the option to specify which **QSGTexture**
    should be exposed to the shader.

    The shader pipeline state changes are less often used. One use case is
    materials that wish to use a specific blend mode. The relevant function is
    **updateGraphicsPipelineState** (). This function is not called unless the
    QSGMaterialShader has opted in by setting the flag
    **UpdatesGraphicsPipelineState** . The task of the function is to update the
    **GraphicsPipelineState**  struct instance that is passed to it with the
    desired changes. Currently only blending and culling-related features are
    available, other states cannot be controlled by materials.

    A minimal example, that also includes texture support, could be the
    following. Here we assume that Material is the **QSGMaterial**  that creates
    an instance of Shader in its **createShader** (), and that it holds a
    **QSGTexture**  we want to sample in the fragment shader. The vertex shader
    relies only on the modelview-projection matrix.

    class Shader : public **QSGMaterialShader**
        {
        public:
    Shader()
            {
                setShaderFileName(VertexStage,
    QLatin1String(":/materialshader.vert.qsb"));
    setShaderFileName(FragmentStage,
    QLatin1String(":/materialshader.frag.qsb"));
            }

            bool
    updateUniformData(RenderState &state, **QSGMaterial**  *, **QSGMaterial**
    *)
            {
                bool changed = false;
                **QByteArray**
    *buf = state.uniformData();
                if (state.isMatrixDirty()) {
    const QMatrix4x4 m = state.combinedMatrix();
    memcpy(buf->data(), m.constData(), 64);
                    changed = true;
    }
                return changed;
            }

            void
    updateSampledImage(RenderState &, int binding, **QSGTexture**  **texture,
    **QSGMaterial**  *newMaterial, **QSGMaterial**  *)
            {
    Material *mat = static_cast<Material *>(newMaterial);
                if
    (binding == 1)
                    *texture = mat->texture();
            }
        };

    The Vulkan-style GLSL source code for the shaders could look like the
    following. These are expected to be preprocessed offline using the `qsb`
    tool, which generates the `.qsb` files referenced in the Shader()
    constructor.

    #version 440
        layout(location = 0) in vec4 aVertex;
        layout(location =
    1) in vec2 aTexCoord;
        layout(location = 0) out vec2 vTexCoord;
    layout(std140, binding = 0) uniform buf {
            mat4 qt_Matrix;
        }
    ubuf;
        out gl_PerVertex { vec4 gl_Position; };
        void main() {
    gl_Position = ubuf.qt_Matrix * aVertex;
            vTexCoord = aTexCoord;
        }

    #version 440
        layout(location = 0) in vec2 vTexCoord;
        layout(location
    = 0) out vec4 fragColor;
        layout(binding = 1) uniform sampler2D srcTex;
    void main() {
            vec4 c = texture(srcTex, vTexCoord);
            fragColor
    = vec4(c.rgb * 0.5, 1.0);
        }

    **Note:** All classes with QSG prefix should be used solely on the scene
    graph's rendering thread. See **Scene Graph and Rendering**  for more
    information.

    **See also** **QSGMaterial** , **Scene Graph - Custom Material** , **Scene
    Graph - Two Texture Providers** , and **Scene Graph - Graph** .
    """

    class Stage(enum.Enum):
        VertexStage: QSGMaterialShader = ...
        FragmentStage: QSGMaterialShader = ...

    class Flag(enum.Flag):
        UpdatesGraphicsPipelineState: QSGMaterialShader = ...

    class RenderState(PyQt6.sip.simplewrapper):
        class DirtyState(enum.Flag):
            DirtyMatrix: QSGMaterialShader = ...
            DirtyOpacity: QSGMaterialShader = ...
            DirtyCachedMaterialData: QSGMaterialShader = ...
            DirtyAll: QSGMaterialShader = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QSGMaterialShader.RenderState") -> None:
            ...

        def uniformData(self) -> QtCore.QByteArray:
            ...

        def devicePixelRatio(self) -> float:
            ...

        def determinant(self) -> float:
            ...

        def deviceRect(self) -> QtCore.QRect:
            ...

        def viewportRect(self) -> QtCore.QRect:
            ...

        def projectionMatrix(self) -> QtGui.QMatrix4x4:
            ...

        def modelViewMatrix(self) -> QtGui.QMatrix4x4:
            ...

        def combinedMatrix(self) -> QtGui.QMatrix4x4:
            ...

        def opacity(self) -> float:
            ...

        def isOpacityDirty(self) -> bool:
            ...

        def isMatrixDirty(self) -> bool:
            ...

        def dirtyStates(self) -> "QSGMaterialShader.RenderState.DirtyState":
            ...

    class GraphicsPipelineState(PyQt6.sip.simplewrapper):
        class CullMode(enum.Enum):
            CullNone: QSGMaterialShader = ...
            CullFront: QSGMaterialShader = ...
            CullBack: QSGMaterialShader = ...

        class ColorMaskComponent(enum.Flag):
            R: QSGMaterialShader = ...
            G: QSGMaterialShader = ...
            B: QSGMaterialShader = ...
            A: QSGMaterialShader = ...

        class BlendFactor(enum.Enum):
            Zero: QSGMaterialShader = ...
            One: QSGMaterialShader = ...
            SrcColor: QSGMaterialShader = ...
            OneMinusSrcColor: QSGMaterialShader = ...
            DstColor: QSGMaterialShader = ...
            OneMinusDstColor: QSGMaterialShader = ...
            SrcAlpha: QSGMaterialShader = ...
            OneMinusSrcAlpha: QSGMaterialShader = ...
            DstAlpha: QSGMaterialShader = ...
            OneMinusDstAlpha: QSGMaterialShader = ...
            ConstantColor: QSGMaterialShader = ...
            OneMinusConstantColor: QSGMaterialShader = ...
            ConstantAlpha: QSGMaterialShader = ...
            OneMinusConstantAlpha: QSGMaterialShader = ...
            SrcAlphaSaturate: QSGMaterialShader = ...
            Src1Color: QSGMaterialShader = ...
            OneMinusSrc1Color: QSGMaterialShader = ...
            Src1Alpha: QSGMaterialShader = ...
            OneMinusSrc1Alpha: QSGMaterialShader = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QSGMaterialShader.GraphicsPipelineState") -> None:
            ...

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsgmaterialshader.html#QSGMaterialShader

        **QSGMaterialShader::QSGMaterialShader()**

        Constructs a new QSGMaterialShader.
        """
        ...

    def setShaderFileName(
        self, stage: "QSGMaterialShader.Stage", filename: str
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsgmaterialshader.html#setShaderFileName

        **[protected] void
        QSGMaterialShader::setShaderFileName(QSGMaterialShader::Stage stage ,
        const QString & filename )**

        Sets the **filename** for the shader for the specified **stage**.

        The file is expected to contain a serialized QShader.
        """
        ...

    def setFlags(self, flags: "QSGMaterialShader.Flag") -> None:
        """
        https://doc.qt.io/qt-6/qsgmaterialshader.html#setFlags

        **void QSGMaterialShader::setFlags(QSGMaterialShader::Flags flags )**

        Sets the **flags** for this material shader.

        **See also** **flags** ().
        """
        ...

    def setFlag(self, flags: "QSGMaterialShader.Flag", on: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsgmaterialshader.html#setFlag

        **void QSGMaterialShader::setFlag(QSGMaterialShader::Flags flags , bool
        on = true)**

        Sets the **flags** on this material shader if **on** is true; otherwise
        clears the specified flags.
        """
        ...

    def flags(self) -> "QSGMaterialShader.Flag":
        """
        https://doc.qt.io/qt-6/qsgmaterialshader.html#flags

        **QSGMaterialShader::Flags QSGMaterialShader::flags() const**

        Returns the currently set flags for this material shader.

        **See also** **setFlags** ().
        """
        ...

    def updateGraphicsPipelineState(
        self,
        state: "QSGMaterialShader.RenderState",
        ps: "QSGMaterialShader.GraphicsPipelineState",
        newMaterial: QSGMaterial,
        oldMaterial: QSGMaterial,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsgmaterialshader.html#updateGraphicsPipelineStat
        e

        **[virtual] bool QSGMaterialShader::updateGraphicsPipelineState(QSGMater
        ialShader::RenderState & state ,
        QSGMaterialShader::GraphicsPipelineState * ps , QSGMaterial *
        newMaterial , QSGMaterial * oldMaterial )**

        This function is called by the scene graph to enable the material to
        provide a custom set of graphics state. The set of states that are
        customizable by material is limited to blending and related settings.

        **Note:** This function is only called when the
        **UpdatesGraphicsPipelineState**  flag was enabled via **setFlags** ().
        By default it is not set, and so this function is never called.

        The return value must be `true` whenever a change was made to any of the
        members in **ps**.

        **Note:** The contents of **ps** is not persistent between invocations
        of this function.

        The current rendering **state** is passed from the scene graph.

        The subclass specific state can be extracted from **newMaterial**. When
        **oldMaterial** is null, this shader was just activated.
        """
        ...

    def updateSampledImage(
        self,
        state: "QSGMaterialShader.RenderState",
        binding: int,
        newMaterial: QSGMaterial,
        oldMaterial: QSGMaterial,
    ) -> "QSGTexture":
        """
        https://doc.qt.io/qt-6/qsgmaterialshader.html#updateSampledImage

        **[virtual] void
        QSGMaterialShader::updateSampledImage(QSGMaterialShader::RenderState &
        state , int binding , QSGTexture ** texture , QSGMaterial * newMaterial
        , QSGMaterial * oldMaterial )**

        This function is called by the scene graph to prepare using a sampled
        image in the shader, typically in form of a combined image sampler.

        **binding** is the binding number of the sampler. The function is called
        for each combined image sampler variable in the shader code associated
        with the **QSGMaterialShader** .

        When * **texture** is null, it must be set to a **QSGTexture**  pointer
        before returning. When non-null, it is up to the material to decide if a
        new `QSGTexture *` is stored to it, or if it updates some parameters on
        the already known **QSGTexture** . The ownership of the **QSGTexture**
        is not transferred.

        The current rendering **state** is passed from the scene graph. Where
        relevant, it is up to the material to trigger enqueuing texture data
        uploads.

        The subclass specific state can be extracted from **newMaterial**.

        **oldMaterial** can be used to minimize changes. When **oldMaterial** is
        null, this shader was just activated.
        """
        ...

    def updateUniformData(
        self,
        state: "QSGMaterialShader.RenderState",
        newMaterial: QSGMaterial,
        oldMaterial: QSGMaterial,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsgmaterialshader.html#updateUniformData

        **[virtual] bool
        QSGMaterialShader::updateUniformData(QSGMaterialShader::RenderState &
        state , QSGMaterial * newMaterial , QSGMaterial * oldMaterial )**

        This function is called by the scene graph to get the contents of the
        shader program's uniform buffer updated. The implementation is not
        expected to perform any real graphics operations, it is merely
        responsible for copying data to the **QByteArray**  returned from
        **RenderState::uniformData** (). The scene graph takes care of making
        that buffer visible in the shaders.

        The current rendering **state** is passed from the scene graph. If the
        state indicates that any relevant state is dirty, the implementation
        must update the appropriate region in the buffer data that is accessible
        via **RenderState::uniformData** (). When a state, such as, matrix or
        opacity, is not dirty, there is no need to touch the corresponding
        region since the data is persistent.

        The return value must be `true` whenever any change was made to the
        uniform data.

        The subclass specific state, such as the color of a flat color material,
        should be extracted from **newMaterial** to update the relevant regions
        in the buffer accordingly.

        **oldMaterial** can be used to minimize buffer changes (which are
        typically memcpy calls) when updating material states. When
        **oldMaterial** is null, this shader was just activated.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QTextOption(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtextoption.html

    **Detailed Description**

    QTextOption is used to encapsulate common rich text properties in a single
    object. It contains information about text alignment, layout direction, word
    wrapping, and other standard properties associated with text rendering and
    layout.

    **See also** **QTextEdit** , **QTextDocument** , and **QTextCursor** .
    """

    class TabType(enum.Enum):
        LeftTab: QTextOption = ...
        RightTab: QTextOption = ...
        CenterTab: QTextOption = ...
        DelimiterTab: QTextOption = ...

    class Flag(enum.Flag):
        IncludeTrailingSpaces: QTextOption = ...
        ShowTabsAndSpaces: QTextOption = ...
        ShowLineAndParagraphSeparators: QTextOption = ...
        AddSpaceForLineAndParagraphSeparators: QTextOption = ...
        SuppressColors: QTextOption = ...
        ShowDocumentTerminator: QTextOption = ...

    class WrapMode(enum.Enum):
        NoWrap: QTextOption = ...
        WordWrap: QTextOption = ...
        ManualWrap: QTextOption = ...
        WrapAnywhere: QTextOption = ...
        WrapAtWordBoundaryOrAnywhere: QTextOption = ...

    class Tab(PyQt6.sip.simplewrapper):
        delimiter: str = ...
        position: float = ...
        type = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(
            self, pos: float, tabType: "QTextOption.TabType", delim: str = ...
        ) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QTextOption.Tab") -> None:
            ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextoption.html#QTextOption

        **QTextOption::QTextOption()**

        Constructs a text option with default properties for text. The text
        alignment property is set to **Qt::AlignLeft** . The word wrap property
        is set to **QTextOption::WordWrap** . The using of design metrics flag
        is set to false.
        """
        ...

    @typing.overload
    def __init__(self, alignment: QtCore.Qt.AlignmentFlag) -> None:
        """
        https://doc.qt.io/qt-6/qtextoption.html#QTextOption-1

        **QTextOption::QTextOption(Qt::Alignment alignment )**

        Constructs a text option with the given **alignment** for text. The word
        wrap property is set to **QTextOption::WordWrap** . The using of design
        metrics flag is set to false.
        """
        ...

    @typing.overload
    def __init__(self, o: "QTextOption") -> None:
        """
        https://doc.qt.io/qt-6/qtextoption.html#QTextOption-2

        **QTextOption::QTextOption(const QTextOption & other )**

        Construct a copy of the **other** text option.
        """
        ...

    def tabStopDistance(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextoption.html#tabStopDistance

        **[since 5.10] qreal QTextOption::tabStopDistance() const**

        Returns the distance in device units between tab stops.

        This function was introduced in Qt 5.10.

        **See also** **setTabStopDistance** (), **tabArray** (), **setTabs** (),
        and **tabs** ().
        """
        ...

    def setTabStopDistance(self, tabStopDistance: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextoption.html#setTabStopDistance

        **[since 5.10] void QTextOption::setTabStopDistance(qreal
        tabStopDistance )**

        Sets the default distance in device units between tab stops to the value
        specified by **tabStopDistance**.

        This function was introduced in Qt 5.10.

        **See also** **tabStopDistance** (), **setTabArray** (), **setTabs** (),
        and **tabs** ().
        """
        ...

    def tabs(self) -> typing.List["QTextOption.Tab"]:
        """
        https://doc.qt.io/qt-6/qtextoption.html#tabs

        **QList<QTextOption::Tab> QTextOption::tabs() const**

        Returns a list of tab positions defined for the text layout.

        **See also** **tabStopDistance** (), **setTabs** (), and
        **setTabStopDistance** ().
        """
        ...

    def setTabs(self, tabStops: typing.Iterable["QTextOption.Tab"]) -> None:
        """
        https://doc.qt.io/qt-6/qtextoption.html#setTabs

        **void QTextOption::setTabs(const QList<QTextOption::Tab> & tabStops )**

        Sets the tab positions for the text layout to those specified by
        **tabStops**.

        **See also** **tabs** () and **tabStopDistance** ().
        """
        ...

    def setFlags(self, flags: "QTextOption.Flag") -> None:
        """
        https://doc.qt.io/qt-6/qtextoption.html#setFlags

        **void QTextOption::setFlags(QTextOption::Flags flags )**

        Sets the flags associated with the option to the given **flags**.

        **See also** **flags** ().
        """
        ...

    def setAlignment(self, aalignment: QtCore.Qt.AlignmentFlag) -> None:
        """
        https://doc.qt.io/qt-6/qtextoption.html#setAlignment

        **void QTextOption::setAlignment(Qt::Alignment alignment )**

        Sets the option's text alignment to the specified **alignment**.

        **See also** **alignment** ().
        """
        ...

    def useDesignMetrics(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextoption.html#useDesignMetrics

        **bool QTextOption::useDesignMetrics() const**

        Returns `true` if the layout uses design rather than device metrics;
        otherwise returns `false`.

        **See also** **setUseDesignMetrics** ().
        """
        ...

    def setUseDesignMetrics(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextoption.html#setUseDesignMetrics

        **void QTextOption::setUseDesignMetrics(bool enable )**

        If **enable** is true then the layout will use design metrics; otherwise
        it will use the metrics of the paint device (which is the default
        behavior).

        **See also** **useDesignMetrics** ().
        """
        ...

    def tabArray(self) -> typing.List[float]:
        """
        https://doc.qt.io/qt-6/qtextoption.html#tabArray

        **QList<qreal> QTextOption::tabArray() const**

        Returns a list of tab positions defined for the text layout.

        **See also** **setTabArray** () and **tabStopDistance** ().
        """
        ...

    def setTabArray(self, tabStops: typing.Iterable[float]) -> None:
        """
        https://doc.qt.io/qt-6/qtextoption.html#setTabArray

        **void QTextOption::setTabArray(const QList<qreal> & tabStops )**

        Sets the tab positions for the text layout to those specified by
        **tabStops**.

        **See also** **tabArray** (), **setTabStopDistance** (), and **setTabs**
        ().
        """
        ...

    def flags(self) -> "QTextOption.Flag":
        """
        https://doc.qt.io/qt-6/qtextoption.html#flags

        **QTextOption::Flags QTextOption::flags() const**

        Returns the flags associated with the option.

        **See also** **setFlags** ().
        """
        ...

    def wrapMode(self) -> "QTextOption.WrapMode":
        """
        https://doc.qt.io/qt-6/qtextoption.html#wrapMode

        **QTextOption::WrapMode QTextOption::wrapMode() const**

        Returns the text wrap mode defined by the option.

        **See also** **setWrapMode** ().
        """
        ...

    def setWrapMode(self, wrap: "QTextOption.WrapMode") -> None:
        """
        https://doc.qt.io/qt-6/qtextoption.html#setWrapMode

        **void QTextOption::setWrapMode(QTextOption::WrapMode mode )**

        Sets the option's text wrap mode to the given **mode**.

        **See also** **wrapMode** ().
        """
        ...

    def textDirection(self) -> QtCore.Qt.LayoutDirection:
        """
        https://doc.qt.io/qt-6/qtextoption.html#textDirection

        **Qt::LayoutDirection QTextOption::textDirection() const**

        Returns the direction of the text layout defined by the option.

        **See also** **setTextDirection** ().
        """
        ...

    def setTextDirection(self, aDirection: QtCore.Qt.LayoutDirection) -> None:
        """
        https://doc.qt.io/qt-6/qtextoption.html#setTextDirection

        **void QTextOption::setTextDirection(Qt::LayoutDirection direction )**

        Sets the direction of the text layout defined by the option to the given
        **direction**.

        **See also** **textDirection** ().
        """
        ...

    def alignment(self) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qtextoption.html#alignment

        **Qt::Alignment QTextOption::alignment() const**

        Returns the text alignment defined by the option.

        **See also** **setAlignment** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6 import QtCore
from PyQt6.QtDesigner import *
import enum


class QDesignerFormWindowInterface(QtWidgets.QWidget):
    """
    https://doc.qt.io/qt-6/qdesignerformwindowinterface.html

    **Detailed Description**

    QDesignerFormWindowInterface provides information about the associated form
    window as well as allowing its properties to be altered. The interface is
    not intended to be instantiated directly, but to provide access to **Qt
    Designer** 's current form windows controlled by **Qt Designer** 's **form
    window manager** .

    If you are looking for the form window containing a specific widget, you can
    use the static **QDesignerFormWindowInterface::findFormWindow** () function:

    **QDesignerFormWindowInterface**  *formWindow;
            formWindow =
    **QDesignerFormWindowInterface** ::findFormWindow(myWidget);

    But in addition, you can access any of the current form windows through **Qt
    Designer** 's form window manager: Use the
    **QDesignerFormEditorInterface::formWindowManager** () function to retrieve
    an interface to the manager. Once you have this interface, you have access
    to all of **Qt Designer** 's current form windows through the
    **QDesignerFormWindowManagerInterface::formWindow** () function. For
    example:

    **QList** <**QDesignerFormWindowInterface**  *> forms;
    **QDesignerFormWindowInterface**  *formWindow;
    **QDesignerFormWindowManagerInterface**  *manager =
    formEditor->formWindowManager();

            for (int i = 0; i <
    manager->formWindowCount(); i++) {
                formWindow =
    manager->formWindow(i);
                forms.append(formWindow);
            }

    The pointer to **Qt Designer** 's current **QDesignerFormEditorInterface**
    object (`formEditor` in the example above) is provided by the
    **QDesignerCustomWidgetInterface::initialize** () function's parameter. When
    implementing a custom widget plugin, you must subclass the
    **QDesignerCustomWidgetInterface**  class to expose your plugin to **Qt
    Designer**.

    Once you have the form window, you can query its properties. For example, a
    plain custom widget plugin is managed by **Qt Designer** only at its top
    level, i.e. none of its child widgets can be resized in **Qt Designer** 's
    workspace. But QDesignerFormWindowInterface provides you with functions that
    enables you to control whether a widget should be managed by **Qt Designer**
    , or not:

    if (formWindow->isManaged(myWidget))
    formWindow->manageWidget(myWidget->childWidget);

    The complete list of functions concerning widget management is:
    **isManaged** (), **manageWidget** () and **unmanageWidget** (). There is
    also several associated signals: **widgetManaged** (), **widgetRemoved** (),
    **aboutToUnmanageWidget** () and **widgetUnmanaged** ().

    In addition to controlling the management of widgets, you can control the
    current selection in the form window using the **selectWidget** (),
    **clearSelection** () and **emitSelectionChanged** () functions, and the
    **selectionChanged** () signal.

    You can also retrieve information about where the form is stored using
    **absoluteDir** (), its include files using **includeHints** (), and its
    layout and pixmap functions using **layoutDefault** (), **layoutFunction**
    () and **pixmapFunction** (). You can find out whether the form window has
    been modified (but not saved) or not, using the **isDirty** () function. You
    can retrieve its **author** (), its **contents** (), its **fileName** (),
    associated **comment** () and **exportMacro** (), its mainContainer(), its
    **features** (), its **grid** () and its **resourceFiles** ().

    The interface provides you with functions and slots allowing you to alter
    most of this information as well. The exception is the directory storing the
    form window. Finally, there is several signals associated with changes to
    the information mentioned above and to the form window in general.

    **See also** **QDesignerFormWindowCursorInterface** ,
    **QDesignerFormEditorInterface** , and
    **QDesignerFormWindowManagerInterface** .
    """

    class FeatureFlag(enum.Flag):
        EditFeature: QDesignerFormWindowInterface = ...
        GridFeature: QDesignerFormWindowInterface = ...
        TabOrderFeature: QDesignerFormWindowInterface = ...
        DefaultFeature: QDesignerFormWindowInterface = ...

    def __init__(
        self,
        parent: typing.Optional[QtWidgets.QWidget] = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#QDesignerFormWi
        ndowInterface

        **QDesignerFormWindowInterface::QDesignerFormWindowInterface(QWidget *
        parent = nullptr, Qt::WindowFlags flags = {})**

        Constructs a form window interface with the given **parent** and the
        specified window **flags**.
        """
        ...

    def activateResourceFilePaths(
        self, paths: typing.Iterable[str]
    ) -> typing.Tuple[int, str]:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#activateResourc
        eFilePaths

        **[slot, since 5.0] void
        QDesignerFormWindowInterface::activateResourceFilePaths(const
        QStringList & paths , int * errorCount = nullptr, QString *
        errorMessages = nullptr)**

        Activates the resource (.qrc) file paths **paths** , returning the count
        of errors in **errorCount** and error message in **errorMessages**. **Qt
        Designer** loads the resources using the **QResource**  class, making
        them available for form editing.

        In IDE integrations, a list of the project's resource (.qrc) file can be
        activated, making them available to **Qt Designer**.

        This function was introduced in Qt 5.0.

        **See also** **activeResourceFilePaths** () and **QResource** .
        """
        ...

    def formContainer(self) -> QtWidgets.QWidget:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#formContainer

        **[pure virtual, since 5.0] QWidget
        *QDesignerFormWindowInterface::formContainer() const**

        Returns the form the widget containing the main container widget.

        This function was introduced in Qt 5.0.
        """
        ...

    def activeResourceFilePaths(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#activeResourceF
        ilePaths

        **[since 5.0] QStringList
        QDesignerFormWindowInterface::activeResourceFilePaths() const**

        Returns the active resource (.qrc) file paths currently loaded in **Qt
        Designer**.

        This function was introduced in Qt 5.0.

        **See also** **activateResourceFilePaths** ().
        """
        ...

    def checkContents(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#checkContents

        **[pure virtual, since 5.0] QStringList
        QDesignerFormWindowInterface::checkContents() const**

        Performs checks on the current form and returns a list of richtext
        warnings about potential issues (for example, top level spacers on
        unlaid-out forms).

        IDE integrations can call this before handling starting a save
        operation.

        This function was introduced in Qt 5.0.
        """
        ...

    def setFileName(self, fileName: str) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#setFileName

        **[pure virtual slot] void
        QDesignerFormWindowInterface::setFileName(const QString & fileName )**

        Sets the file name for the form to the given **fileName**.

        **See also** **fileName** () and **fileNameChanged** ().
        """
        ...

    def setGrid(self, grid: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#setGrid

        **[pure virtual slot] void QDesignerFormWindowInterface::setGrid(const
        QPoint & grid )**

        Sets the grid size for the form window to the point specified by
        **grid**. In this function, the coordinates in the **QPoint**  are used
        to specify the dimensions of a rectangle in the grid.

        **See also** **grid** ().
        """
        ...

    def selectWidget(self, widget: QtWidgets.QWidget, select: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#selectWidget

        **[pure virtual slot] void
        QDesignerFormWindowInterface::selectWidget(QWidget * widget , bool
        select = true)**

        If **select** is true, the given **widget** is selected; otherwise the
        **widget** is deselected.

        **See also** **clearSelection** () and **selectionChanged** ().
        """
        ...

    def clearSelection(self, update: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#clearSelection

        **[pure virtual slot] void
        QDesignerFormWindowInterface::clearSelection(bool update = true)**

        Clears the current selection in the form window. If **update** is true,
        the **emitSelectionChanged** () function is called, emitting the
        **selectionChanged** () signal.

        **See also** **selectWidget** ().
        """
        ...

    def setDirty(self, dirty: bool) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#setDirty

        **[pure virtual slot] void QDesignerFormWindowInterface::setDirty(bool
        dirty )**

        If **dirty** is true, the form window is marked as dirty, meaning that
        it is modified but not saved. If **dirty** is false, the form window is
        considered to be unmodified.

        **See also** **isDirty** ().
        """
        ...

    def setFeatures(self, f: "QDesignerFormWindowInterface.FeatureFlag") -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#setFeatures

        **[pure virtual slot] void QDesignerFormWindowInterface::setFeatures(QDe
        signerFormWindowInterface::Feature features )**

        Enables the specified **features** for the form window.

        **See also** **features** () and **featureChanged** ().
        """
        ...

    def unmanageWidget(self, widget: QtWidgets.QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#unmanageWidget

        **[pure virtual slot] void
        QDesignerFormWindowInterface::unmanageWidget(QWidget * widget )**

        Instructs the form window not to manage the specified **widget**.

        **See also** **aboutToUnmanageWidget** () and **widgetUnmanaged** ().
        """
        ...

    def manageWidget(self, widget: QtWidgets.QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#manageWidget

        **[pure virtual slot] void
        QDesignerFormWindowInterface::manageWidget(QWidget * widget )**

        Instructs the form window to manage the specified **widget**.

        **See also** **isManaged** (), **unmanageWidget** (), and
        **widgetManaged** ().
        """
        ...

    def removeResourceFile(self, path: str) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#removeResourceF
        ile

        **[pure virtual] void
        QDesignerFormWindowInterface::removeResourceFile(const QString & path
        )**

        Removes the resource file at the specified **path** from the list of
        those used by the form.

        **See also** **resourceFiles** () and **resourceFilesChanged** ().
        """
        ...

    def addResourceFile(self, path: str) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#addResourceFile

        **[pure virtual] void
        QDesignerFormWindowInterface::addResourceFile(const QString & path )**

        Adds the resource file at the given **path** to those used by the form.

        **See also** **resourceFiles** () and **resourceFilesChanged** ().
        """
        ...

    def resourceFiles(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#resourceFiles

        **[pure virtual] QStringList
        QDesignerFormWindowInterface::resourceFiles() const**

        Returns a list of paths to resource files that are currently being used
        by the form window.

        **See also** **addResourceFile** () and **removeResourceFile** ().
        """
        ...

    def emitSelectionChanged(self) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#emitSelectionCh
        anged

        **[pure virtual] void
        QDesignerFormWindowInterface::emitSelectionChanged()**

        Emits the **selectionChanged** () signal.

        **See also** **selectWidget** () and **clearSelection** ().
        """
        ...

    @typing.overload
    @staticmethod
    def findFormWindow(w: QtWidgets.QWidget) -> "QDesignerFormWindowInterface":
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#findFormWindow

        **[static] QDesignerFormWindowInterface
        *QDesignerFormWindowInterface::findFormWindow(QWidget * widget )**

        Returns the form window interface for the given **widget**.
        """
        ...

    @typing.overload
    @staticmethod
    def findFormWindow(obj: QtCore.QObject) -> "QDesignerFormWindowInterface":
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#findFormWindow-
        1

        **[static] QDesignerFormWindowInterface
        *QDesignerFormWindowInterface::findFormWindow(QObject * object )**

        Returns the form window interface for the given **object**.
        """
        ...

    def isDirty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#isDirty

        **[pure virtual] bool QDesignerFormWindowInterface::isDirty() const**

        Returns true if the form window is "dirty" (modified but not saved);
        otherwise returns false.

        **See also** **setDirty** ().
        """
        ...

    def isManaged(self, widget: QtWidgets.QWidget) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#isManaged

        **[pure virtual] bool QDesignerFormWindowInterface::isManaged(QWidget *
        widget ) const**

        Returns true if the specified **widget** is managed by the form window;
        otherwise returns false.

        **See also** **manageWidget** ().
        """
        ...

    def setMainContainer(self, mainContainer: QtWidgets.QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#setMainContaine
        r

        **[pure virtual] void
        QDesignerFormWindowInterface::setMainContainer(QWidget * mainContainer
        )**

        Sets the main container widget on the form to the specified
        **mainContainer**.

        **See also** **mainContainerChanged** ().
        """
        ...

    def mainContainer(self) -> QtWidgets.QWidget:
        ...

    def grid(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#grid

        **[pure virtual] QPoint QDesignerFormWindowInterface::grid() const**

        Returns the grid spacing used by the form window.

        **See also** **setGrid** ().
        """
        ...

    def cursor(self) -> "QDesignerFormWindowCursorInterface":
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#cursor

        **[pure virtual] QDesignerFormWindowCursorInterface
        *QDesignerFormWindowInterface::cursor() const**

        Returns the cursor interface used by the form window.
        """
        ...

    def core(self) -> QDesignerFormEditorInterface:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#core

        **[virtual] QDesignerFormEditorInterface
        *QDesignerFormWindowInterface::core() const**

        Returns a pointer to **Qt Designer** 's current
        **QDesignerFormEditorInterface**  object.
        """
        ...

    def setIncludeHints(self, includeHints: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#setIncludeHints

        **[pure virtual] void
        QDesignerFormWindowInterface::setIncludeHints(const QStringList &
        includeHints )**

        Sets the header files that will be included in the form window's
        associated UI file to the specified **includeHints**.

        Header files may be local, i.e. relative to the project's directory,
        `"mywidget.h"`, or global, i.e. part of Qt or the compilers standard
        libraries: `<QtGui/QWidget>`.

        **See also** **includeHints** ().
        """
        ...

    def includeHints(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#includeHints

        **[pure virtual] QStringList
        QDesignerFormWindowInterface::includeHints() const**

        Returns a list of the header files that will be included in the form
        window's associated UI file.

        Header files may be local, i.e. relative to the project's directory,
        `"mywidget.h"`, or global, i.e. part of Qt or the compilers standard
        libraries: `<QtGui/QWidget>`.

        **See also** **setIncludeHints** ().
        """
        ...

    def setExportMacro(self, exportMacro: str) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#setExportMacro

        **[pure virtual] void QDesignerFormWindowInterface::setExportMacro(const
        QString & exportMacro )**

        Sets the form window's export macro to **exportMacro**. The export macro
        is used when building a widget plugin to export the form's interface to
        other components.

        **See also** **exportMacro** ().
        """
        ...

    def exportMacro(self) -> str:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#exportMacro

        **[pure virtual] QString QDesignerFormWindowInterface::exportMacro()
        const**

        Returns the export macro associated with the form currently being
        displayed in the window. The export macro is used when the form is
        compiled to create a widget plugin.

        **See also** **setExportMacro** () and **Creating Custom Widgets for Qt
        Designer** .
        """
        ...

    def setPixmapFunction(self, pixmapFunction: str) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#setPixmapFuncti
        on

        **[pure virtual] void
        QDesignerFormWindowInterface::setPixmapFunction(const QString &
        pixmapFunction )**

        Sets the function used to load pixmaps into the form window to the given
        **pixmapFunction**.

        **See also** **pixmapFunction** ().
        """
        ...

    def pixmapFunction(self) -> str:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#pixmapFunction

        **[pure virtual] QString QDesignerFormWindowInterface::pixmapFunction()
        const**

        Returns the name of the function used to load pixmaps into the form
        window.

        **See also** **setPixmapFunction** ().
        """
        ...

    def setLayoutFunction(self, margin: str, spacing: str) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#setLayoutFuncti
        on

        **[pure virtual] void
        QDesignerFormWindowInterface::setLayoutFunction(const QString & margin ,
        const QString & spacing )**

        Sets the **margin** and **spacing** for the form's layout.

        The default layout properties will be replaced by the corresponding
        layout functions when `uic` generates code for the form, that is, if the
        functions are specified. This is useful when different environments
        requires different layouts for the same form.

        **See also** **layoutFunction** ().
        """
        ...

    def layoutFunction(self) -> typing.Tuple[str, str]:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#layoutFunction

        **[pure virtual] void
        QDesignerFormWindowInterface::layoutFunction(QString * margin , QString
        * spacing )**

        Fills in the current margin and spacing for the form's layout in the
        **margin** and **spacing** variables specified.

        **See also** **setLayoutFunction** ().
        """
        ...

    def setLayoutDefault(self, margin: int, spacing: int) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#setLayoutDefaul
        t

        **[pure virtual] void QDesignerFormWindowInterface::setLayoutDefault(int
        margin , int spacing )**

        Sets the default **margin** and **spacing** for the form's layout.

        **See also** **layoutDefault** ().
        """
        ...

    def layoutDefault(self) -> typing.Tuple[int, int]:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#layoutDefault

        **[pure virtual] void QDesignerFormWindowInterface::layoutDefault(int *
        margin , int * spacing )**

        Fills in the default margin and spacing for the form's default layout in
        the **margin** and **spacing** variables specified.

        **See also** **setLayoutDefault** ().
        """
        ...

    def setComment(self, comment: str) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#setComment

        **[pure virtual] void QDesignerFormWindowInterface::setComment(const
        QString & comment )**

        Sets the information about the form to the **comment** specified. This
        information should be a human-readable comment about the form.

        **See also** **comment** ().
        """
        ...

    def comment(self) -> str:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#comment

        **[pure virtual] QString QDesignerFormWindowInterface::comment() const**

        Returns comments about the form currently being displayed in the window.

        **See also** **setComment** ().
        """
        ...

    def setAuthor(self, author: str) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#setAuthor

        **[pure virtual] void QDesignerFormWindowInterface::setAuthor(const
        QString & author )**

        Sets the details for the author or creator of the form to the **author**
        specified.

        **See also** **author** ().
        """
        ...

    def author(self) -> str:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#author

        **[pure virtual] QString QDesignerFormWindowInterface::author() const**

        Returns details of the author or creator of the form currently being
        displayed in the window.

        **See also** **setAuthor** ().
        """
        ...

    def hasFeature(self, f: "QDesignerFormWindowInterface.FeatureFlag") -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#hasFeature

        **[pure virtual] bool QDesignerFormWindowInterface::hasFeature(QDesigner
        FormWindowInterface::Feature feature ) const**

        Returns true if the form window offers the specified **feature** ;
        otherwise returns false.

        **See also** **features** ().
        """
        ...

    def features(self) -> "QDesignerFormWindowInterface.FeatureFlag":
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#features

        **[pure virtual] QDesignerFormWindowInterface::Feature
        QDesignerFormWindowInterface::features() const**

        Returns a combination of the features provided by the form window
        associated with the interface. The value returned can be tested against
        the **Feature**  enum values to determine which features are supported
        by the window.

        **See also** **setFeatures** () and **hasFeature** ().
        """
        ...

    @typing.overload
    def setContents(
        self, dev: QtCore.QIODevice, errorMessage: typing.Optional[str] = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#setContents

        **[pure virtual] bool
        QDesignerFormWindowInterface::setContents(QIODevice * device , QString *
        errorMessage = 0)**

        Sets the form's contents using data obtained from the given **device**
        and returns whether loading succeeded. If it fails, the error message is
        returned in **errorMessage**.

        Data can be read from **QFile**  objects or any other subclass of
        **QIODevice** .

        **See also** **contents** ().
        """
        ...

    @typing.overload
    def setContents(self, contents: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#setContents-1

        **[pure virtual slot] bool
        QDesignerFormWindowInterface::setContents(const QString & contents )**

        Sets the contents of the form using data read from the specified
        **contents** string and returns whether the operation succeeded.

        **See also** **contents** ().
        """
        ...

    def contents(self) -> str:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#contents

        **[pure virtual] QString QDesignerFormWindowInterface::contents()
        const**

        Returns details of the contents of the form currently being displayed in
        the window.

        **See also** **setContents** ().
        """
        ...

    def absoluteDir(self) -> QtCore.QDir:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#absoluteDir

        **[pure virtual] QDir QDesignerFormWindowInterface::absoluteDir()
        const**

        Returns the absolute location of the directory containing the form shown
        in the form window.
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#fileName

        **[pure virtual] QString QDesignerFormWindowInterface::fileName()
        const**

        Returns the file name of the UI file that describes the form currently
        being shown.

        **See also** **setFileName** ().
        """
        ...

    @property
    def aboutToUnmanageWidget(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#aboutToUnmanage
        Widget

        **[signal] void
        QDesignerFormWindowInterface::aboutToUnmanageWidget(QWidget * widget )**

        This signal is emitted whenever a widget on the form is about to become
        unmanaged. When this signal is emitted, the specified **widget** is
        still managed, and a **widgetUnmanaged** () signal will follow,
        indicating when it is no longer managed.

        **See also** **unmanageWidget** () and **isManaged** ().
        """
        ...

    @property
    def activated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#activated

        **[signal] void QDesignerFormWindowInterface::activated(QWidget * widget
        )**

        This signal is emitted whenever a widget is activated on the form. The
        activated widget is specified by **widget**.
        """
        ...

    @property
    def changed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#changed

        **[signal] void QDesignerFormWindowInterface::changed()**

        This signal is emitted whenever a form is changed.
        """
        ...

    @property
    def featureChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#featureChanged

        **[signal] void QDesignerFormWindowInterface::featureChanged(QDesignerFo
        rmWindowInterface::Feature feature )**

        This signal is emitted whenever a feature changes in the form. The new
        feature is specified by **feature**.

        **See also** **setFeatures** ().
        """
        ...

    @property
    def fileNameChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#fileNameChanged

        **[signal] void QDesignerFormWindowInterface::fileNameChanged(const
        QString & fileName )**

        This signal is emitted whenever the file name of the form changes. The
        new file name is specified by **fileName**.

        **See also** **setFileName** ().
        """
        ...

    @property
    def geometryChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#geometryChanged

        **[signal] void QDesignerFormWindowInterface::geometryChanged()**

        This signal is emitted whenever the form's geometry changes.
        """
        ...

    @property
    def mainContainerChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#mainContainerCh
        anged

        **[signal] void
        QDesignerFormWindowInterface::mainContainerChanged(QWidget *
        mainContainer )**

        This signal is emitted whenever the main container changes. The new
        container is specified by **mainContainer**.

        **See also** **setMainContainer** ().
        """
        ...

    @property
    def objectRemoved(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#objectRemoved

        **[signal] void QDesignerFormWindowInterface::objectRemoved(QObject *
        object )**

        This signal is emitted whenever an object (such as an action or a
        **QButtonGroup** ) is removed from the form. The object that was removed
        is specified by **object**.
        """
        ...

    @property
    def resourceFilesChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#resourceFilesCh
        anged

        **[signal] void QDesignerFormWindowInterface::resourceFilesChanged()**

        This signal is emitted whenever the list of resource files used by the
        form changes.

        **See also** **resourceFiles** ().
        """
        ...

    @property
    def selectionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#selectionChange
        d

        **[signal] void QDesignerFormWindowInterface::selectionChanged()**

        This signal is emitted whenever the selection in the form changes.

        **See also** **selectWidget** () and **clearSelection** ().
        """
        ...

    @property
    def widgetManaged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#widgetManaged

        **[signal] void QDesignerFormWindowInterface::widgetManaged(QWidget *
        widget )**

        This signal is emitted whenever a widget on the form becomes managed.
        The newly managed widget is specified by **widget**.

        **See also** **manageWidget** ().
        """
        ...

    @property
    def widgetRemoved(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#widgetRemoved

        **[signal] void QDesignerFormWindowInterface::widgetRemoved(QWidget *
        widget )**

        This signal is emitted whenever a widget is removed from the form. The
        widget that was removed is specified by **widget**.
        """
        ...

    @property
    def widgetUnmanaged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowinterface.html#widgetUnmanaged

        **[signal] void QDesignerFormWindowInterface::widgetUnmanaged(QWidget *
        widget )**

        This signal is emitted whenever a widget on the form becomes unmanaged.
        The newly released widget is specified by **widget**.

        **See also** **unmanageWidget** () and **aboutToUnmanageWidget** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtNetwork import *


class QAbstractNetworkCache(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qabstractnetworkcache.html

    **Detailed Description**

    QAbstractNetworkCache is the base class for every standard cache that is
    used by **QNetworkAccessManager** . QAbstractNetworkCache is an abstract
    class and cannot be instantiated.

    **See also** **QNetworkDiskCache** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qabstractnetworkcache.html#QAbstractNetworkCache

        **[protected] QAbstractNetworkCache::QAbstractNetworkCache(QObject *
        parent = nullptr)**

        Constructs an abstract network cache with the given **parent**.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractnetworkcache.html#clear

        **[pure virtual slot] void QAbstractNetworkCache::clear()**

        Removes all items from the cache. Unless there was failures clearing the
        cache **cacheSize** () should return 0 after a call to clear.

        In the base class this is a pure virtual function.

        **See also** **cacheSize** () and **remove** ().
        """
        ...

    def insert(self, device: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qabstractnetworkcache.html#insert

        **[pure virtual] void QAbstractNetworkCache::insert(QIODevice * device
        )**

        Inserts the data in **device** and the prepared meta data into the
        cache. After this function is called the data and meta data should be
        retrievable using **data** () and **metaData** ().

        To cancel a prepared inserted call **remove** () on the metadata's url.

        In the base class this is a pure virtual function.

        **See also** **prepare** () and **remove** ().
        """
        ...

    def prepare(self, metaData: QNetworkCacheMetaData) -> QtCore.QIODevice:
        """
        https://doc.qt.io/qt-6/qabstractnetworkcache.html#prepare

        **[pure virtual] QIODevice *QAbstractNetworkCache::prepare(const
        QNetworkCacheMetaData & metaData )**

        Returns the device that should be populated with the data for the cache
        item **metaData**. When all of the data has been written **insert** ()
        should be called. If **metaData**  is invalid or the url in the metadata
        is invalid `nullptr` is returned.

        The cache owns the device and will take care of deleting it when it is
        inserted or removed.

        To cancel a prepared inserted call **remove** () on the metadata's url.

        In the base class this is a pure virtual function.

        **See also** **remove** (), **updateMetaData** (), and **insert** ().
        """
        ...

    def cacheSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractnetworkcache.html#cacheSize

        **[pure virtual] qint64 QAbstractNetworkCache::cacheSize() const**

        Returns the current size taken up by the cache. Depending upon the cache
        implementation this might be disk or memory size.

        In the base class this is a pure virtual function.

        **See also** **clear** ().
        """
        ...

    def remove(self, url: QtCore.QUrl) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractnetworkcache.html#remove

        **[pure virtual] bool QAbstractNetworkCache::remove(const QUrl & url )**

        Removes the cache entry for **url** , returning true if success
        otherwise false.

        In the base class this is a pure virtual function.

        **See also** **clear** () and **prepare** ().
        """
        ...

    def data(self, url: QtCore.QUrl) -> QtCore.QIODevice:
        """
        https://doc.qt.io/qt-6/qabstractnetworkcache.html#data

        **[pure virtual] QIODevice *QAbstractNetworkCache::data(const QUrl & url
        )**

        Returns the data associated with **url**.

        It is up to the application that requests the data to delete the
        **QIODevice**  when done with it.

        If there is no cache for **url** , the url is invalid, or if there is an
        internal cache error `nullptr` is returned.

        In the base class this is a pure virtual function.

        **See also** **metaData** () and **prepare** ().
        """
        ...

    def updateMetaData(self, metaData: QNetworkCacheMetaData) -> None:
        """
        https://doc.qt.io/qt-6/qabstractnetworkcache.html#updateMetaData

        **[pure virtual] void QAbstractNetworkCache::updateMetaData(const
        QNetworkCacheMetaData & metaData )**

        Updates the cache meta date for the **metaData** 's url to **metaData**

        If the cache does not contains a cache item for the url then no action
        is taken.

        In the base class this is a pure virtual function.

        **See also** **metaData** () and **prepare** ().
        """
        ...

    def metaData(self, url: QtCore.QUrl) -> QNetworkCacheMetaData:
        """
        https://doc.qt.io/qt-6/qabstractnetworkcache.html#metaData

        **[pure virtual] QNetworkCacheMetaData
        QAbstractNetworkCache::metaData(const QUrl & url )**

        Returns the meta data for the url **url**.

        If the url is valid and the cache contains the data for url, a valid
        **QNetworkCacheMetaData**  is returned.

        In the base class this is a pure virtual function.

        **See also** **updateMetaData** () and **data** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtWidgets
from PyQt6.QtPrintSupport import *
import enum


class QAbstractPrintDialog(QtWidgets.QDialog):
    """
    https://doc.qt.io/qt-6/qabstractprintdialog.html

    **Detailed Description**

    This class implements getter and setter functions that are used to customize
    settings shown in print dialogs, but it is not used directly. Use
    **QPrintDialog**  to display a print dialog in your application.

    **See also** **QPrintDialog**  and **QPrinter** .
    """

    class PrintDialogOption(enum.Flag):
        PrintToFile: QAbstractPrintDialog = ...
        PrintSelection: QAbstractPrintDialog = ...
        PrintPageRange: QAbstractPrintDialog = ...
        PrintCollateCopies: QAbstractPrintDialog = ...
        PrintShowPageSize: QAbstractPrintDialog = ...
        PrintCurrentPage: QAbstractPrintDialog = ...

    class PrintRange(enum.Enum):
        AllPages: QAbstractPrintDialog = ...
        Selection: QAbstractPrintDialog = ...
        PageRange: QAbstractPrintDialog = ...
        CurrentPage: QAbstractPrintDialog = ...

    def __init__(
        self, printer: "QPrinter", parent: typing.Optional[QtWidgets.QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractprintdialog.html#QAbstractPrintDialog

        **QAbstractPrintDialog::QAbstractPrintDialog(QPrinter * printer ,
        QWidget * parent = nullptr)**

        Constructs an abstract print dialog for **printer** with **parent** as
        parent widget.
        """
        ...

    def setOptionTabs(self, tabs: typing.Iterable[QtWidgets.QWidget]) -> None:
        """
        https://doc.qt.io/qt-6/qabstractprintdialog.html#setOptionTabs

        **void QAbstractPrintDialog::setOptionTabs(const QList<QWidget *> & tabs
        )**

        Set a list of widgets as **tabs** to be shown on the print dialog, if
        supported.

        Currently this option is only supported on X11.

        Setting the option tabs will transfer their ownership to the print
        dialog.
        """
        ...

    def printer(self) -> "QPrinter":
        """
        https://doc.qt.io/qt-6/qabstractprintdialog.html#printer

        **QPrinter *QAbstractPrintDialog::printer() const**

        Returns the printer that this printer dialog operates on.
        """
        ...

    def toPage(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractprintdialog.html#toPage

        **int QAbstractPrintDialog::toPage() const**

        Returns the last page to be printed. By default, this value is set to 0.
        """
        ...

    def fromPage(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractprintdialog.html#fromPage

        **int QAbstractPrintDialog::fromPage() const**

        Returns the first page to be printed By default, this value is set to 0.
        """
        ...

    def setFromTo(self, fromPage: int, toPage: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractprintdialog.html#setFromTo

        **void QAbstractPrintDialog::setFromTo(int from , int to )**

        Sets the range in the print dialog to be from **from** to **to**.
        """
        ...

    def maxPage(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractprintdialog.html#maxPage

        **int QAbstractPrintDialog::maxPage() const**

        Returns the maximum page in the page range. As of Qt 4.4, this function
        returns INT_MAX by default. Previous versions returned 1 by default.
        """
        ...

    def minPage(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractprintdialog.html#minPage

        **int QAbstractPrintDialog::minPage() const**

        Returns the minimum page in the page range. By default, this value is
        set to 1.
        """
        ...

    def setMinMax(self, min: int, max: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractprintdialog.html#setMinMax

        **void QAbstractPrintDialog::setMinMax(int min , int max )**

        Sets the page range in this dialog to be from **min** to **max**. This
        also enables the **PrintPageRange**  option.
        """
        ...

    def printRange(self) -> "QAbstractPrintDialog.PrintRange":
        """
        https://doc.qt.io/qt-6/qabstractprintdialog.html#printRange

        **QAbstractPrintDialog::PrintRange QAbstractPrintDialog::printRange()
        const**

        Returns the print range.

        **See also** **setPrintRange** ().
        """
        ...

    def setPrintRange(self, range: "QAbstractPrintDialog.PrintRange") -> None:
        """
        https://doc.qt.io/qt-6/qabstractprintdialog.html#setPrintRange

        **void
        QAbstractPrintDialog::setPrintRange(QAbstractPrintDialog::PrintRange
        range )**

        Sets the print range option in to be **range**.

        **See also** **printRange** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtTest import *
import enum


class QTest(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtest.html

    **Detailed Description**

    See the **Qt Test Overview**  for information about how to write unit tests.
    """

    class KeyAction(enum.Enum):
        Press: QTest = ...
        Release: QTest = ...
        Click: QTest = ...
        Shortcut: QTest = ...

    @typing.overload
    def qWaitForWindowExposed(self, window: QtGui.QWindow, timeout: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qtest.html#qWaitForWindowExposed

        **[since 5.0] bool QTest::qWaitForWindowExposed(QWindow * window , int
        timeout = 5000)**

        Waits for **timeout** milliseconds or until the **window** is exposed.
        Returns `true` if `window` is exposed within **timeout** milliseconds,
        otherwise returns `false`.

        This is mainly useful for asynchronous systems like X11, where a window
        will be mapped to screen some time after being asked to show itself on
        the screen.

        Note that a window that is mapped to screen may still not be considered
        exposed if the window client area is completely covered by other
        windows, or if the window is otherwise not visible. This function will
        then time out when waiting for such a window.

        This function was introduced in Qt 5.0.

        **See also** **qWaitForWindowActive** () and **QWindow::isExposed** ().
        """
        ...

    @typing.overload
    def qWaitForWindowExposed(
        self, widget: QtWidgets.QWidget, timeout: int = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtest.html#qWaitForWindowExposed-1

        **[since 5.0] bool QTest::qWaitForWindowExposed(QWidget * widget , int
        timeout = 5000)**

        Waits for **timeout** milliseconds or until the **widget** 's window is
        exposed. Returns `true` if `widget`'s window is exposed within
        **timeout** milliseconds, otherwise returns `false`.

        This is mainly useful for asynchronous systems like X11, where a window
        will be mapped to screen some time after being asked to show itself on
        the screen.

        Note that a window that is mapped to screen may still not be considered
        exposed if the window client area is completely covered by other
        windows, or if the window is otherwise not visible. This function will
        then time out when waiting for such a window.

        A specific configuration where this happens is when using QGLWidget as a
        viewport widget on macOS: The viewport widget gets the expose event, not
        the parent widget.

        This function was introduced in Qt 5.0.

        **See also** **qWaitForWindowActive** ().
        """
        ...

    @typing.overload
    def qWaitForWindowActive(self, window: QtGui.QWindow, timeout: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qtest.html#qWaitForWindowActive

        **[since 5.0] bool QTest::qWaitForWindowActive(QWindow * window , int
        timeout = 5000)**

        Waits for **timeout** milliseconds or until the **window** is active.

        Returns `true` if `window` is active within **timeout** milliseconds,
        otherwise returns `false`.

        This function was introduced in Qt 5.0.

        **See also** **qWaitForWindowExposed** () and **QWindow::isActive** ().
        """
        ...

    @typing.overload
    def qWaitForWindowActive(
        self, widget: QtWidgets.QWidget, timeout: int = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtest.html#qWaitForWindowActive-1

        **[since 5.0] bool QTest::qWaitForWindowActive(QWidget * widget , int
        timeout = 5000)**

        Waits for **timeout** milliseconds or until the **widget** 's window is
        active.

        Returns `true` if `widget`'s window is active within **timeout**
        milliseconds, otherwise returns `false`.

        This function was introduced in Qt 5.0.

        **See also** **qWaitForWindowExposed** () and
        **QWidget::isActiveWindow** ().
        """
        ...

    def qWait(self, ms: int) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#qWait

        **void QTest::qWait(int ms )**

        Waits for **ms** milliseconds. While waiting, events will be processed
        and your test will stay responsive to user interface events or network
        communication.

        Example:

        int i = 0;
                while (myNetworkServerNotResponding() && i++ < 50)
        QTest::qWait(250);

        The code above will wait until the network server is responding for a
        maximum of about 12.5 seconds.

        **See also** **QTest::qSleep** () and **QSignalSpy::wait** ().
        """
        ...

    @typing.overload
    def mouseRelease(
        self,
        widget: QtWidgets.QWidget,
        button: QtCore.Qt.MouseButton,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        pos: QtCore.QPoint = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#mouseRelease

        **void QTest::mouseRelease(QWidget * widget , Qt::MouseButton button ,
        Qt::KeyboardModifiers modifier = Qt::KeyboardModifiers(), QPoint pos =
        QPoint(), int delay = -1)**

        Simulates releasing a mouse **button** with an optional **modifier** on
        a **widget**. The position of the release is defined by **pos** ; the
        default position is the center of the widget. If **delay** is specified,
        the test will wait for the specified amount of milliseconds before
        releasing the button.

        **See also** **QTest::mousePress** () and **QTest::mouseClick** ().
        """
        ...

    @typing.overload
    def mouseRelease(
        self,
        window: QtGui.QWindow,
        button: QtCore.Qt.MouseButton,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        pos: QtCore.QPoint = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#mouseRelease-1

        **[since 5.0] void QTest::mouseRelease(QWindow * window ,
        Qt::MouseButton button , Qt::KeyboardModifiers stateKey =
        Qt::KeyboardModifiers(), QPoint pos = QPoint(), int delay = -1)**

        This is an overloaded function.

        Simulates releasing a mouse **button** with an optional **stateKey**
        modifier on a **window**. The position of the release is defined by
        **pos** ; the default position is the center of the window. If **delay**
        is specified, the test will wait for the specified amount of
        milliseconds before releasing the button.

        This function was introduced in Qt 5.0.

        **See also** **QTest::mousePress** () and **QTest::mouseClick** ().
        """
        ...

    @typing.overload
    def mousePress(
        self,
        widget: QtWidgets.QWidget,
        button: QtCore.Qt.MouseButton,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        pos: QtCore.QPoint = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#mousePress

        **void QTest::mousePress(QWidget * widget , Qt::MouseButton button ,
        Qt::KeyboardModifiers modifier = Qt::KeyboardModifiers(), QPoint pos =
        QPoint(), int delay = -1)**

        Simulates pressing a mouse **button** with an optional **modifier** on a
        **widget**. The position is defined by **pos** ; the default position is
        the center of the widget. If **delay** is specified, the test will wait
        for the specified amount of milliseconds before the press.

        **See also** **QTest::mouseRelease** () and **QTest::mouseClick** ().
        """
        ...

    @typing.overload
    def mousePress(
        self,
        window: QtGui.QWindow,
        button: QtCore.Qt.MouseButton,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        pos: QtCore.QPoint = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#mousePress-1

        **[since 5.0] void QTest::mousePress(QWindow * window , Qt::MouseButton
        button , Qt::KeyboardModifiers stateKey = Qt::KeyboardModifiers(),
        QPoint pos = QPoint(), int delay = -1)**

        This is an overloaded function.

        Simulates pressing a mouse **button** with an optional **stateKey**
        modifier on a **window**. The position is defined by **pos** ; the
        default position is the center of the window. If **delay** is specified,
        the test will wait for the specified amount of milliseconds before the
        press.

        This function was introduced in Qt 5.0.

        **See also** **QTest::mouseRelease** () and **QTest::mouseClick** ().
        """
        ...

    @typing.overload
    def mouseMove(
        self, widget: QtWidgets.QWidget, pos: QtCore.QPoint = ..., delay: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#mouseMove

        **void QTest::mouseMove(QWidget * widget , QPoint pos = QPoint(), int
        delay = -1)**

        Moves the mouse pointer to a **widget**. If **pos** is not specified,
        the mouse pointer moves to the center of the widget. If a **delay** (in
        milliseconds) is given, the test will wait before moving the mouse
        pointer.
        """
        ...

    @typing.overload
    def mouseMove(
        self, window: QtGui.QWindow, pos: QtCore.QPoint = ..., delay: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#mouseMove-1

        **[since 5.0] void QTest::mouseMove(QWindow * window , QPoint pos =
        QPoint(), int delay = -1)**

        This is an overloaded function.

        Moves the mouse pointer to a **window**. If **pos** is not specified,
        the mouse pointer moves to the center of the window. If a **delay** (in
        milliseconds) is given, the test will wait before moving the mouse
        pointer.

        This function was introduced in Qt 5.0.
        """
        ...

    @typing.overload
    def mouseDClick(
        self,
        widget: QtWidgets.QWidget,
        button: QtCore.Qt.MouseButton,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        pos: QtCore.QPoint = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#mouseDClick

        **void QTest::mouseDClick(QWidget * widget , Qt::MouseButton button ,
        Qt::KeyboardModifiers modifier = Qt::KeyboardModifiers(), QPoint pos =
        QPoint(), int delay = -1)**

        Simulates double clicking a mouse **button** with an optional
        **modifier** on a **widget**. The position of the click is defined by
        **pos** ; the default position is the center of the widget. If **delay**
        is specified, the test will wait for the specified amount of
        milliseconds before each press and release.

        **See also** **QTest::mouseClick** ().
        """
        ...

    @typing.overload
    def mouseDClick(
        self,
        window: QtGui.QWindow,
        button: QtCore.Qt.MouseButton,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        pos: QtCore.QPoint = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#mouseDClick-1

        **[since 5.0] void QTest::mouseDClick(QWindow * window , Qt::MouseButton
        button , Qt::KeyboardModifiers stateKey = Qt::KeyboardModifiers(),
        QPoint pos = QPoint(), int delay = -1)**

        This is an overloaded function.

        Simulates double clicking a mouse **button** with an optional
        **stateKey** modifier on a **window**. The position of the click is
        defined by **pos** ; the default position is the center of the window.
        If **delay** is specified, the test will wait for the specified amount
        of milliseconds before each press and release.

        This function was introduced in Qt 5.0.

        **See also** **QTest::mouseClick** ().
        """
        ...

    @typing.overload
    def mouseClick(
        self,
        widget: QtWidgets.QWidget,
        button: QtCore.Qt.MouseButton,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        pos: QtCore.QPoint = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#mouseClick

        **void QTest::mouseClick(QWidget * widget , Qt::MouseButton button ,
        Qt::KeyboardModifiers modifier = Qt::KeyboardModifiers(), QPoint pos =
        QPoint(), int delay = -1)**

        Simulates clicking a mouse **button** with an optional **modifier** on a
        **widget**. The position of the click is defined by **pos** ; the
        default position is the center of the widget. If **delay** is specified,
        the test will wait for the specified amount of milliseconds before
        pressing and before releasing the button.

        **See also** **QTest::mousePress** () and **QTest::mouseRelease** ().
        """
        ...

    @typing.overload
    def mouseClick(
        self,
        window: QtGui.QWindow,
        button: QtCore.Qt.MouseButton,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        pos: QtCore.QPoint = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#mouseClick-1

        **[since 5.0] void QTest::mouseClick(QWindow * window , Qt::MouseButton
        button , Qt::KeyboardModifiers stateKey = Qt::KeyboardModifiers(),
        QPoint pos = QPoint(), int delay = -1)**

        This is an overloaded function.

        Simulates clicking a mouse **button** with an optional **stateKey**
        modifier on a **window**. The position of the click is defined by
        **pos** ; the default position is the center of the window. If **delay**
        is specified, the test will wait for the specified amount of
        milliseconds before pressing and before releasing the button.

        This function was introduced in Qt 5.0.

        **See also** **QTest::mousePress** () and **QTest::mouseRelease** ().
        """
        ...

    @typing.overload
    def sendKeyEvent(
        self,
        action: "QTest.KeyAction",
        widget: QtWidgets.QWidget,
        code: QtCore.Qt.Key,
        ascii: str,
        modifier: QtCore.Qt.KeyboardModifier,
        delay: int = ...,
    ) -> None:
        ...

    @typing.overload
    def sendKeyEvent(
        self,
        action: "QTest.KeyAction",
        widget: QtWidgets.QWidget,
        code: QtCore.Qt.Key,
        text: str,
        modifier: QtCore.Qt.KeyboardModifier,
        delay: int = ...,
    ) -> None:
        ...

    def simulateEvent(
        self,
        widget: QtWidgets.QWidget,
        press: bool,
        code: int,
        modifier: QtCore.Qt.KeyboardModifier,
        text: str,
        repeat: bool,
        delay: int = ...,
    ) -> None:
        ...

    @typing.overload
    def keySequence(
        self,
        widget: QtWidgets.QWidget,
        keySequence: typing.Union[
            QtGui.QKeySequence, QtGui.QKeySequence.StandardKey, str, int
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keySequence

        **[since 5.10] void QTest::keySequence(QWindow * window , const
        QKeySequence & keySequence )**

        This is an overloaded function.

        Simulates typing of **keySequence** into a **window**.

        This function was introduced in Qt 5.10.

        **See also** **QTest::keyClick** () and **QTest::keyClicks** ().
        """
        ...

    @typing.overload
    def keySequence(
        self,
        window: QtGui.QWindow,
        keySequence: typing.Union[
            QtGui.QKeySequence, QtGui.QKeySequence.StandardKey, str, int
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keySequence-1

        **[since 5.10] void QTest::keySequence(QWidget * widget , const
        QKeySequence & keySequence )**

        This is an overloaded function.

        Simulates typing of **keySequence** into a **widget**.

        This function was introduced in Qt 5.10.

        **See also** **QTest::keyClick** () and **QTest::keyClicks** ().
        """
        ...

    @typing.overload
    def keyRelease(
        self,
        widget: QtWidgets.QWidget,
        key: QtCore.Qt.Key,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyRelease

        **void QTest::keyRelease(QWidget * widget , Qt::Key key ,
        Qt::KeyboardModifiers modifier = Qt::NoModifier, int delay = -1)**

        Simulates releasing a **key** with an optional **modifier** on a
        **widget**. If **delay** is larger than 0, the test will wait for
        **delay** milliseconds before releasing the key.

        **See also** **QTest::keyPress** () and **QTest::keyClick** ().
        """
        ...

    @typing.overload
    def keyRelease(
        self,
        widget: QtWidgets.QWidget,
        key: str,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyRelease-1

        **[since 5.0] void QTest::keyRelease(QWindow * window , char key ,
        Qt::KeyboardModifiers modifier = Qt::NoModifier, int delay = -1)**

        This is an overloaded function.

        Simulates releasing a **key** with an optional **modifier** on a
        **window**. If **delay** is larger than 0, the test will wait for
        **delay** milliseconds before releasing the key.

        This function was introduced in Qt 5.0.

        **See also** **QTest::keyClick** ().
        """
        ...

    @typing.overload
    def keyRelease(
        self,
        window: QtGui.QWindow,
        key: QtCore.Qt.Key,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyRelease-2

        **[since 5.0] void QTest::keyRelease(QWindow * window , Qt::Key key ,
        Qt::KeyboardModifiers modifier = Qt::NoModifier, int delay = -1)**

        This is an overloaded function.

        Simulates releasing a **key** with an optional **modifier** on a
        **window**. If **delay** is larger than 0, the test will wait for
        **delay** milliseconds before releasing the key.

        This function was introduced in Qt 5.0.

        **See also** **QTest::keyPress** () and **QTest::keyClick** ().
        """
        ...

    @typing.overload
    def keyRelease(
        self,
        window: QtGui.QWindow,
        key: str,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyRelease-3

        **void QTest::keyRelease(QWidget * widget , char key ,
        Qt::KeyboardModifiers modifier = Qt::NoModifier, int delay = -1)**

        This is an overloaded function.

        Simulates releasing a **key** with an optional **modifier** on a
        **widget**. If **delay** is larger than 0, the test will wait for
        **delay** milliseconds before releasing the key.

        **See also** **QTest::keyClick** ().
        """
        ...

    @typing.overload
    def keyPress(
        self,
        widget: QtWidgets.QWidget,
        key: QtCore.Qt.Key,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyPress

        **void QTest::keyPress(QWidget * widget , Qt::Key key ,
        Qt::KeyboardModifiers modifier = Qt::NoModifier, int delay = -1)**

        Simulates pressing a **key** with an optional **modifier** on a
        **widget**. If **delay** is larger than 0, the test will wait for
        **delay** milliseconds before pressing the key.

        **Note:** At some point you should release the key using **keyRelease**
        ().

        **See also** **QTest::keyRelease** () and **QTest::keyClick** ().
        """
        ...

    @typing.overload
    def keyPress(
        self,
        widget: QtWidgets.QWidget,
        key: str,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyPress-1

        **[since 5.0] void QTest::keyPress(QWindow * window , char key ,
        Qt::KeyboardModifiers modifier = Qt::NoModifier, int delay = -1)**

        This is an overloaded function.

        Simulates pressing a **key** with an optional **modifier** on a
        **window**. If **delay** is larger than 0, the test will wait for
        **delay** milliseconds before pressing the key.

        **Note:** At some point you should release the key using **keyRelease**
        ().

        This function was introduced in Qt 5.0.

        **See also** **QTest::keyRelease** () and **QTest::keyClick** ().
        """
        ...

    @typing.overload
    def keyPress(
        self,
        window: QtGui.QWindow,
        key: QtCore.Qt.Key,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyPress-2

        **[since 5.0] void QTest::keyPress(QWindow * window , Qt::Key key ,
        Qt::KeyboardModifiers modifier = Qt::NoModifier, int delay = -1)**

        This is an overloaded function.

        Simulates pressing a **key** with an optional **modifier** on a
        **window**. If **delay** is larger than 0, the test will wait for
        **delay** milliseconds before pressing the key.

        **Note:** At some point you should release the key using **keyRelease**
        ().

        This function was introduced in Qt 5.0.

        **See also** **QTest::keyRelease** () and **QTest::keyClick** ().
        """
        ...

    @typing.overload
    def keyPress(
        self,
        window: QtGui.QWindow,
        key: str,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyPress-3

        **void QTest::keyPress(QWidget * widget , char key ,
        Qt::KeyboardModifiers modifier = Qt::NoModifier, int delay = -1)**

        This is an overloaded function.

        Simulates pressing a **key** with an optional **modifier** on a
        **widget**. If **delay** is larger than 0, the test will wait for
        **delay** milliseconds before pressing the key.

        **Note:** At some point you should release the key using **keyRelease**
        ().

        **See also** **QTest::keyRelease** () and **QTest::keyClick** ().
        """
        ...

    @typing.overload
    def keyEvent(
        self,
        action: "QTest.KeyAction",
        widget: QtWidgets.QWidget,
        key: QtCore.Qt.Key,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyEvent

        **void QTest::keyEvent(QTest::KeyAction action , QWidget * widget ,
        Qt::Key key , Qt::KeyboardModifiers modifier = Qt::NoModifier, int delay
        = -1)**

        Sends a Qt key event to **widget** with the given **key** and an
        associated **action**. Optionally, a keyboard **modifier** can be
        specified, as well as a **delay** (in milliseconds) of the test before
        sending the event.
        """
        ...

    @typing.overload
    def keyEvent(
        self,
        action: "QTest.KeyAction",
        widget: QtWidgets.QWidget,
        ascii: str,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyEvent-1

        **[since 5.0] void QTest::keyEvent(QTest::KeyAction action , QWindow *
        window , char ascii , Qt::KeyboardModifiers modifier = Qt::NoModifier,
        int delay = -1)**

        This is an overloaded function.

        Sends a Qt key event to **window** with the given key **ascii** and an
        associated **action**. Optionally, a keyboard **modifier** can be
        specified, as well as a **delay** (in milliseconds) of the test before
        sending the event.

        This function was introduced in Qt 5.0.
        """
        ...

    @typing.overload
    def keyEvent(
        self,
        action: "QTest.KeyAction",
        window: QtGui.QWindow,
        key: QtCore.Qt.Key,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyEvent-2

        **[since 5.0] void QTest::keyEvent(QTest::KeyAction action , QWindow *
        window , Qt::Key key , Qt::KeyboardModifiers modifier = Qt::NoModifier,
        int delay = -1)**

        This is an overloaded function.

        Sends a Qt key event to **window** with the given **key** and an
        associated **action**. Optionally, a keyboard **modifier** can be
        specified, as well as a **delay** (in milliseconds) of the test before
        sending the event.

        This function was introduced in Qt 5.0.
        """
        ...

    @typing.overload
    def keyEvent(
        self,
        action: "QTest.KeyAction",
        window: QtGui.QWindow,
        ascii: str,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyEvent-3

        **void QTest::keyEvent(QTest::KeyAction action , QWidget * widget , char
        ascii , Qt::KeyboardModifiers modifier = Qt::NoModifier, int delay =
        -1)**

        This is an overloaded function.

        Sends a Qt key event to **widget** with the given key **ascii** and an
        associated **action**. Optionally, a keyboard **modifier** can be
        specified, as well as a **delay** (in milliseconds) of the test before
        sending the event.
        """
        ...

    def keyClicks(
        self,
        widget: QtWidgets.QWidget,
        sequence: str,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyClicks

        **void QTest::keyClicks(QWidget * widget , const QString & sequence ,
        Qt::KeyboardModifiers modifier = Qt::NoModifier, int delay = -1)**

        Simulates clicking a **sequence** of keys on a **widget**. Optionally, a
        keyboard **modifier** can be specified as well as a **delay** (in
        milliseconds) of the test before each key click.

        Example:

        QTest::keyClicks(myWidget, "hello world");

        The example above simulates clicking the sequence of keys representing
        "hello world" on `myWidget` without any keyboard modifiers and without
        delay of the test.

        **See also** **QTest::keyClick** ().
        """
        ...

    @typing.overload
    def keyClick(
        self,
        widget: QtWidgets.QWidget,
        key: QtCore.Qt.Key,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyClick

        **void QTest::keyClick(QWidget * widget , Qt::Key key ,
        Qt::KeyboardModifiers modifier = Qt::NoModifier, int delay = -1)**

        Simulates clicking of **key** with an optional **modifier** on a
        **widget**. If **delay** is larger than 0, the test will wait for
        **delay** milliseconds before clicking the key.

        Examples:

        QTest::keyClick(myWidget, Qt::Key_Escape);
        QTest::keyClick(myWidget, Qt::Key_Escape, Qt::ShiftModifier, 200);

        The first example above simulates clicking the `escape` key on
        `myWidget` without any keyboard modifiers and without delay. The second
        example simulates clicking `shift-escape` on `myWidget` following a 200
        ms delay of the test.

        **See also** **QTest::keyClicks** ().
        """
        ...

    @typing.overload
    def keyClick(
        self,
        widget: QtWidgets.QWidget,
        key: str,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyClick-1

        **[since 5.0] void QTest::keyClick(QWindow * window , Qt::Key key ,
        Qt::KeyboardModifiers modifier = Qt::NoModifier, int delay = -1)**

        This is an overloaded function.

        Simulates clicking of **key** with an optional **modifier** on a
        **window**. If **delay** is larger than 0, the test will wait for
        **delay** milliseconds before clicking the key.

        Examples:

        QTest::keyClick(&myWindow, Qt::Key_Escape);
        QTest::keyClick(&myWindow, Qt::Key_Escape, Qt::ShiftModifier, 200);

        The first example above simulates clicking the `escape` key on
        `myWindow` without any keyboard modifiers and without delay. The second
        example simulates clicking `shift-escape` on `myWindow` following a 200
        ms delay of the test.

        This function was introduced in Qt 5.0.

        **See also** **QTest::keyClicks** ().
        """
        ...

    @typing.overload
    def keyClick(
        self,
        window: QtGui.QWindow,
        key: QtCore.Qt.Key,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyClick-2

        **[since 5.0] void QTest::keyClick(QWindow * window , char key ,
        Qt::KeyboardModifiers modifier = Qt::NoModifier, int delay = -1)**

        This is an overloaded function.

        Simulates clicking of **key** with an optional **modifier** on a
        **window**. If **delay** is larger than 0, the test will wait for
        **delay** milliseconds before clicking the key.

        Example:

        **QWidget**  myWindow;
            QTest::keyClick(&myWindow, Qt::Key_Tab);

        The example above simulates clicking `a` on `myWindow` without any
        keyboard modifiers and without delay of the test.

        This function was introduced in Qt 5.0.

        **See also** **QTest::keyClicks** ().
        """
        ...

    @typing.overload
    def keyClick(
        self,
        window: QtGui.QWindow,
        key: str,
        modifier: QtCore.Qt.KeyboardModifier = ...,
        delay: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtest.html#keyClick-3

        **void QTest::keyClick(QWidget * widget , char key ,
        Qt::KeyboardModifiers modifier = Qt::NoModifier, int delay = -1)**

        This is an overloaded function.

        Simulates clicking of **key** with an optional **modifier** on a
        **widget**. If **delay** is larger than 0, the test will wait for
        **delay** milliseconds before clicking the key.

        Example:

        QTest::keyClick(myWidget, 'a');

        The example above simulates clicking `a` on `myWidget` without any
        keyboard modifiers and without delay of the test.

        **See also** **QTest::keyClicks** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QTextBlock(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qtextblock.html

    **Detailed Description**

    A text block encapsulates a block or paragraph of text in a
    **QTextDocument** . QTextBlock provides read-only access to the
    block/paragraph structure of QTextDocuments. It is mainly of use if you want
    to implement your own layouts for the visual representation of a
    **QTextDocument** , or if you want to iterate over a document and write out
    the contents in your own custom format.

    Text blocks are created by their parent documents. If you need to create a
    new text block, or modify the contents of a document while examining its
    contents, use the cursor-based interface provided by **QTextCursor**
    instead.

    Each text block is located at a specific **position** () in a **document**
    (). The contents of the block can be obtained by using the **text** ()
    function. The **length** () function determines the block's size within the
    document (including formatting characters). The visual properties of the
    block are determined by its text **layout** (), its **charFormat** (), and
    its **blockFormat** ().

    The **next** () and **previous** () functions enable iteration over
    consecutive valid blocks in a document under the condition that the document
    is not modified by other means during the iteration process. Note that,
    although blocks are returned in sequence, adjacent blocks may come from
    different places in the document structure. The validity of a block can be
    determined by calling **isValid** ().

    QTextBlock provides comparison operators to make it easier to work with
    blocks: **operator==** () compares two block for equality, **operator!=** ()
    compares two blocks for inequality, and **operator<** () determines whether
    a block precedes another in the same document.

    ![](images/qtextblock-sequence.png)

    **See also** **QTextBlockFormat** , **QTextCharFormat** , and
    **QTextFragment** .
    """

    class iterator(PyQt6.sip.simplewrapper):
        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QTextBlock.iterator") -> None:
            ...

        def atEnd(self) -> bool:
            ...

        def fragment(self) -> "QTextFragment":
            ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextblock.html#QTextBlock-2

        **QTextBlock::QTextBlock(const QTextBlock & other )**

        Copies the **other** text block's attributes to this text block.
        """
        ...

    @typing.overload
    def __init__(self, o: "QTextBlock") -> None:
        """
        https://doc.qt.io/qt-6/qtextblock.html#QTextBlock-2

        **QTextBlock::QTextBlock(const QTextBlock & other )**

        Copies the **other** text block's attributes to this text block.
        """
        ...

    def textFormats(self) -> typing.List[QTextLayout.FormatRange]:
        """
        https://doc.qt.io/qt-6/qtextblock.html#textFormats

        **[since 5.3] QList<QTextLayout::FormatRange> QTextBlock::textFormats()
        const**

        Returns the block's text format options as a list of continuous ranges
        of **QTextCharFormat** . The range's character format is used when
        inserting text within the range boundaries.

        This function was introduced in Qt 5.3.

        **See also** **charFormat** () and **blockFormat** ().
        """
        ...

    def textDirection(self) -> QtCore.Qt.LayoutDirection:
        """
        https://doc.qt.io/qt-6/qtextblock.html#textDirection

        **Qt::LayoutDirection QTextBlock::textDirection() const**

        Returns the resolved text direction.

        If the block has no explicit direction set, it will resolve the
        direction from the blocks content. Returns either **Qt::LeftToRight**
        or **Qt::RightToLeft** .

        **See also** **QTextFormat::layoutDirection** (),
        **QString::isRightToLeft** (), and **Qt::LayoutDirection** .
        """
        ...

    def lineCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextblock.html#lineCount

        **int QTextBlock::lineCount() const**

        Returns the line count. Not all document layouts support this feature.

        **See also** **setLineCount** ().
        """
        ...

    def setLineCount(self, count: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextblock.html#setLineCount

        **void QTextBlock::setLineCount(int count )**

        Sets the line count to **count**.

        **See also** **lineCount** ().
        """
        ...

    def firstLineNumber(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextblock.html#firstLineNumber

        **int QTextBlock::firstLineNumber() const**

        Returns the first line number of this block, or -1 if the block is
        invalid. Unless the layout supports it, the line number is identical to
        the block number.

        **See also** **QTextBlock::blockNumber** ().
        """
        ...

    def blockNumber(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextblock.html#blockNumber

        **int QTextBlock::blockNumber() const**

        Returns the number of this block, or -1 if the block is invalid.

        **See also** **QTextCursor::blockNumber** ().
        """
        ...

    def setVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextblock.html#setVisible

        **void QTextBlock::setVisible(bool visible )**

        Sets the block's visibility to **visible**.

        **See also** **isVisible** ().
        """
        ...

    def isVisible(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextblock.html#isVisible

        **bool QTextBlock::isVisible() const**

        Returns `true` if the block is visible; otherwise returns `false`.

        **See also** **setVisible** ().
        """
        ...

    def setRevision(self, rev: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextblock.html#setRevision

        **void QTextBlock::setRevision(int rev )**

        Sets a blocks revision to **rev**.

        **See also** **revision** () and **QTextDocument::revision** ().
        """
        ...

    def revision(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextblock.html#revision

        **int QTextBlock::revision() const**

        Returns the blocks revision.

        **See also** **setRevision** () and **QTextDocument::revision** ().
        """
        ...

    def clearLayout(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextblock.html#clearLayout

        **void QTextBlock::clearLayout()**

        Clears the **QTextLayout**  that is used to lay out and display the
        block's contents.

        **See also** **layout** ().
        """
        ...

    def setUserState(self, state: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextblock.html#setUserState

        **void QTextBlock::setUserState(int state )**

        Stores the specified **state** integer value in the text block. This may
        be useful for example in a syntax highlighter to store a text parsing
        state.

        **See also** **userState** ().
        """
        ...

    def userState(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextblock.html#userState

        **int QTextBlock::userState() const**

        Returns the integer value previously set with **setUserState** () or -1.

        **See also** **setUserState** ().
        """
        ...

    def setUserData(self, data: "QTextBlockUserData") -> None:
        """
        https://doc.qt.io/qt-6/qtextblock.html#setUserData

        **void QTextBlock::setUserData(QTextBlockUserData * data )**

        Attaches the given **data** object to the text block.

        **QTextBlockUserData**  can be used to store custom settings. The
        ownership is passed to the underlying text document, i.e. the provided
        **QTextBlockUserData**  object will be deleted if the corresponding text
        block gets deleted. The user data object is not stored in the undo
        history, so it will not be available after undoing the deletion of a
        text block.

        For example, if you write a programming editor in an IDE, you may want
        to let your user set breakpoints visually in your code for an integrated
        debugger. In a programming editor a line of text usually corresponds to
        one **QTextBlock** . The **QTextBlockUserData**  interface allows the
        developer to store data for each **QTextBlock** , like for example in
        which lines of the source code the user has a breakpoint set. Of course
        this could also be stored externally, but by storing it inside the
        **QTextDocument** , it will for example be automatically deleted when
        the user deletes the associated line. It's really just a way to store
        custom information in the **QTextDocument**  without using custom
        properties in **QTextFormat**  which would affect the undo/redo stack.

        **See also** **userData** ().
        """
        ...

    def userData(self) -> "QTextBlockUserData":
        """
        https://doc.qt.io/qt-6/qtextblock.html#userData

        **QTextBlockUserData *QTextBlock::userData() const**

        Returns a pointer to a **QTextBlockUserData**  object, if one has been
        set with **setUserData** (), or `nullptr`.

        **See also** **setUserData** ().
        """
        ...

    def previous(self) -> "QTextBlock":
        """
        https://doc.qt.io/qt-6/qtextblock.html#previous

        **QTextBlock QTextBlock::previous() const**

        Returns the text block in the document before this block, or an empty
        text block if this is the first one.

        Note that the previous block may be in a different frame or table to
        this block.

        **See also** **next** (), **begin** (), and **end** ().
        """
        ...

    def next(self) -> "QTextBlock":
        """
        https://doc.qt.io/qt-6/qtextblock.html#next

        **QTextBlock QTextBlock::next() const**

        Returns the text block in the document after this block, or an empty
        text block if this is the last one.

        Note that the next block may be in a different frame or table to this
        block.

        **See also** **previous** (), **begin** (), and **end** ().
        """
        ...

    def end(self) -> "QTextBlock.iterator":
        """
        https://doc.qt.io/qt-6/qtextblock.html#end

        **QTextBlock::iterator QTextBlock::end() const**

        Returns a text block iterator pointing to the end of the text block.

        **See also** **begin** (), **next** (), and **previous** ().
        """
        ...

    def begin(self) -> "QTextBlock.iterator":
        """
        https://doc.qt.io/qt-6/qtextblock.html#begin

        **QTextBlock::iterator QTextBlock::begin() const**

        Returns a text block iterator pointing to the beginning of the text
        block.

        **See also** **end** ().
        """
        ...

    def textList(self) -> QTextList:
        """
        https://doc.qt.io/qt-6/qtextblock.html#textList

        **QTextList *QTextBlock::textList() const**

        If the block represents a list item, returns the list that the item
        belongs to; otherwise returns `nullptr`.
        """
        ...

    def document(self) -> QTextDocument:
        """
        https://doc.qt.io/qt-6/qtextblock.html#document

        **const QTextDocument *QTextBlock::document() const**

        Returns the text document this text block belongs to, or `nullptr` if
        the text block does not belong to any document.
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextblock.html#text

        **QString QTextBlock::text() const**

        Returns the block's contents as plain text.

        **See also** **length** (), **charFormat** (), and **blockFormat** ().
        """
        ...

    def charFormatIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextblock.html#charFormatIndex

        **int QTextBlock::charFormatIndex() const**

        Returns an index into the document's internal list of character formats
        for the text block's character format.

        **See also** **QTextDocument::allFormats** ().
        """
        ...

    def charFormat(self) -> QTextCharFormat:
        """
        https://doc.qt.io/qt-6/qtextblock.html#charFormat

        **QTextCharFormat QTextBlock::charFormat() const**

        Returns the **QTextCharFormat**  that describes the block's character
        format. The block's character format is used when inserting text into an
        empty block.

        **See also** **blockFormat** ().
        """
        ...

    def blockFormatIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextblock.html#blockFormatIndex

        **int QTextBlock::blockFormatIndex() const**

        Returns an index into the document's internal list of block formats for
        the text block's format.

        **See also** **QTextDocument::allFormats** ().
        """
        ...

    def blockFormat(self) -> QTextBlockFormat:
        """
        https://doc.qt.io/qt-6/qtextblock.html#blockFormat

        **QTextBlockFormat QTextBlock::blockFormat() const**

        Returns the **QTextBlockFormat**  that describes block-specific
        properties.

        **See also** **charFormat** ().
        """
        ...

    def layout(self) -> QTextLayout:
        """
        https://doc.qt.io/qt-6/qtextblock.html#layout

        **QTextLayout *QTextBlock::layout() const**

        Returns the **QTextLayout**  that is used to lay out and display the
        block's contents.

        Note that the returned **QTextLayout**  object can only be modified from
        the documentChanged implementation of a **QAbstractTextDocumentLayout**
        subclass. Any changes applied from the outside cause undefined behavior.

        **See also** **clearLayout** ().
        """
        ...

    def contains(self, position: int) -> bool:
        """
        https://doc.qt.io/qt-6/qtextblock.html#contains

        **bool QTextBlock::contains(int position ) const**

        Returns `true` if the given **position** is located within the text
        block; otherwise returns `false`.
        """
        ...

    def length(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextblock.html#length

        **int QTextBlock::length() const**

        Returns the length of the block in characters.

        **Note:** The length returned includes all formatting characters, for
        example, newline.

        **See also** **text** (), **charFormat** (), and **blockFormat** ().
        """
        ...

    def position(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextblock.html#position

        **int QTextBlock::position() const**

        Returns the index of the block's first character within the document.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextblock.html#isValid

        **bool QTextBlock::isValid() const**

        Returns `true` if this text block is valid; otherwise returns `false`.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtGui import *


class QTextTable(QTextFrame):
    """
    https://doc.qt.io/qt-6/qtexttable.html

    **Detailed Description**

    A table is a group of cells ordered into rows and columns. Each table
    contains at least one row and one column. Each cell contains a block, and is
    surrounded by a frame.

    Tables are usually created and inserted into a document with the
    **QTextCursor::insertTable** () function. For example, we can insert a table
    with three rows and two columns at the current cursor position in an editor
    using the following lines of code:

    **QTextCursor**  cursor(editor->textCursor());
    cursor.movePosition(**QTextCursor** ::Start);

            QTextTable *table
    = cursor.insertTable(rows, columns, tableFormat);

    The table format is either defined when the table is created or changed
    later with **setFormat** ().

    The table currently being edited by the cursor is found with
    **QTextCursor::currentTable** (). This allows its format or dimensions to be
    changed after it has been inserted into a document.

    A table's size can be changed with **resize** (), or by using **insertRows**
    (), **insertColumns** (), **removeRows** (), or **removeColumns** (). Use
    **cellAt** () to retrieve table cells.

    The starting and ending positions of table rows can be found by moving a
    cursor within a table, and using the **rowStart** () and **rowEnd** ()
    functions to obtain cursors at the start and end of each row.

    Rows and columns within a QTextTable can be merged and split using the
    **mergeCells** () and **splitCell** () functions. However, only cells that
    span multiple rows or columns can be split. (Merging or splitting does not
    increase or decrease the number of rows and columns.)

    Note that if you have merged multiple columns and rows into one cell, you
    will not be able to split the merged cell into new cells spanning over more
    than one row or column. To be able to split cells spanning over several rows
    and columns you need to do this over several iterations.

    ![Original Table](images/texttable-split.png)Suppose we have a 2x3 table of
    names and addresses. To merge both columns in the first row we invoke
    **mergeCells** () with **row** = 0, **column** = 0, **numRows** = 1 and
    **numColumns** = 2.



            table->mergeCells(0, 0, 1, 2);
    ![](images/texttable-merge.png)This gives us the following table. To split
    the first row of the table back into two cells, we invoke the **splitCell**
    () function with **numRows** and **numCols** = 1.
    table->splitCell(0, 0, 1, 1);

    ![Split Table](images/texttable-
    split.png)This results in the original table.

    **See also** **QTextTableFormat** .
    """

    def __init__(self, doc: QTextDocument) -> None:
        ...

    def appendColumns(self, count: int) -> None:
        """
        https://doc.qt.io/qt-6/qtexttable.html#appendColumns

        **void QTextTable::appendColumns(int count )**

        Appends **count** columns at the right side of the table.

        **See also** **insertColumns** (), **insertRows** (), **resize** (),
        **removeRows** (), **removeColumns** (), and **appendRows** ().
        """
        ...

    def appendRows(self, count: int) -> None:
        """
        https://doc.qt.io/qt-6/qtexttable.html#appendRows

        **void QTextTable::appendRows(int count )**

        Appends **count** rows at the bottom of the table.

        **See also** **insertColumns** (), **insertRows** (), **resize** (),
        **removeRows** (), **removeColumns** (), and **appendColumns** ().
        """
        ...

    def setFormat(self, aformat: QTextTableFormat) -> None:
        """
        https://doc.qt.io/qt-6/qtexttable.html#setFormat

        **void QTextTable::setFormat(const QTextTableFormat & format )**

        Sets the table's **format**.

        **See also** **format** ().
        """
        ...

    def format(self) -> QTextTableFormat:
        """
        https://doc.qt.io/qt-6/qtexttable.html#format

        **QTextTableFormat QTextTable::format() const**

        Returns the table's format.

        **See also** **setFormat** ().
        """
        ...

    def rowEnd(self, c: QTextCursor) -> QTextCursor:
        """
        https://doc.qt.io/qt-6/qtexttable.html#rowEnd

        **QTextCursor QTextTable::rowEnd(const QTextCursor & cursor ) const**

        Returns a cursor pointing to the end of the row that contains the given
        **cursor**.

        **See also** **rowStart** ().
        """
        ...

    def rowStart(self, c: QTextCursor) -> QTextCursor:
        """
        https://doc.qt.io/qt-6/qtexttable.html#rowStart

        **QTextCursor QTextTable::rowStart(const QTextCursor & cursor ) const**

        Returns a cursor pointing to the start of the row that contains the
        given **cursor**.

        **See also** **rowEnd** ().
        """
        ...

    @typing.overload
    def cellAt(self, row: int, col: int) -> QTextTableCell:
        """
        https://doc.qt.io/qt-6/qtexttable.html#cellAt

        **QTextTableCell QTextTable::cellAt(int row , int column ) const**

        Returns the table cell at the given **row** and **column** in the table.

        **See also** **columns** () and **rows** ().
        """
        ...

    @typing.overload
    def cellAt(self, position: int) -> QTextTableCell:
        """
        https://doc.qt.io/qt-6/qtexttable.html#cellAt-1

        **QTextTableCell QTextTable::cellAt(int position ) const**

        This is an overloaded function.

        Returns the table cell that contains the character at the given
        **position** in the document.
        """
        ...

    @typing.overload
    def cellAt(self, c: QTextCursor) -> QTextTableCell:
        """
        https://doc.qt.io/qt-6/qtexttable.html#cellAt-2

        **QTextTableCell QTextTable::cellAt(const QTextCursor & cursor ) const**

        This is an overloaded function.

        Returns the table cell containing the given **cursor**.
        """
        ...

    def columns(self) -> int:
        """
        https://doc.qt.io/qt-6/qtexttable.html#columns

        **int QTextTable::columns() const**

        Returns the number of columns in the table.

        **See also** **rows** ().
        """
        ...

    def rows(self) -> int:
        """
        https://doc.qt.io/qt-6/qtexttable.html#rows

        **int QTextTable::rows() const**

        Returns the number of rows in the table.

        **See also** **columns** ().
        """
        ...

    def splitCell(self, row: int, col: int, numRows: int, numCols: int) -> None:
        """
        https://doc.qt.io/qt-6/qtexttable.html#splitCell

        **void QTextTable::splitCell(int row , int column , int numRows , int
        numCols )**

        Splits the specified cell at **row** and **column** into an array of
        multiple cells with dimensions specified by **numRows** and **numCols**.

        **Note:** It is only possible to split cells that span multiple rows or
        columns, such as rows that have been merged using **mergeCells** ().

        **See also** **mergeCells** ().
        """
        ...

    @typing.overload
    def mergeCells(self, row: int, col: int, numRows: int, numCols: int) -> None:
        """
        https://doc.qt.io/qt-6/qtexttable.html#mergeCells

        **void QTextTable::mergeCells(int row , int column , int numRows , int
        numCols )**

        Merges the cell at the specified **row** and **column** with the
        adjacent cells into one cell. The new cell will span **numRows** rows
        and **numCols** columns. This method does nothing if **numRows** or
        **numCols** is less than the current number of rows or columns spanned
        by the cell.

        **See also** **splitCell** ().
        """
        ...

    @typing.overload
    def mergeCells(self, cursor: QTextCursor) -> None:
        """
        https://doc.qt.io/qt-6/qtexttable.html#mergeCells-1

        **void QTextTable::mergeCells(const QTextCursor & cursor )**

        This is an overloaded function.

        Merges the cells selected by the provided **cursor**.

        **See also** **splitCell** ().
        """
        ...

    def removeColumns(self, pos: int, num: int) -> None:
        """
        https://doc.qt.io/qt-6/qtexttable.html#removeColumns

        **void QTextTable::removeColumns(int index , int columns )**

        Removes a number of **columns** starting with the column at the
        specified **index**.

        **See also** **insertRows** (), **insertColumns** (), **removeRows** (),
        **resize** (), **appendRows** (), and **appendColumns** ().
        """
        ...

    def removeRows(self, pos: int, num: int) -> None:
        """
        https://doc.qt.io/qt-6/qtexttable.html#removeRows

        **void QTextTable::removeRows(int index , int rows )**

        Removes a number of **rows** starting with the row at the specified
        **index**.

        **See also** **insertRows** (), **insertColumns** (), **resize** (),
        **removeColumns** (), **appendRows** (), and **appendColumns** ().
        """
        ...

    def insertColumns(self, pos: int, num: int) -> None:
        """
        https://doc.qt.io/qt-6/qtexttable.html#insertColumns

        **void QTextTable::insertColumns(int index , int columns )**

        Inserts a number of **columns** before the column with the specified
        **index**.

        **See also** **insertRows** (), **resize** (), **removeRows** (),
        **removeColumns** (), **appendRows** (), and **appendColumns** ().
        """
        ...

    def insertRows(self, pos: int, num: int) -> None:
        """
        https://doc.qt.io/qt-6/qtexttable.html#insertRows

        **void QTextTable::insertRows(int index , int rows )**

        Inserts a number of **rows** before the row with the specified
        **index**.

        **See also** **resize** (), **insertColumns** (), **removeRows** (),
        **removeColumns** (), **appendRows** (), and **appendColumns** ().
        """
        ...

    def resize(self, rows: int, cols: int) -> None:
        """
        https://doc.qt.io/qt-6/qtexttable.html#resize

        **void QTextTable::resize(int rows , int columns )**

        Resizes the table to contain the required number of **rows** and
        **columns**.

        **See also** **insertRows** (), **insertColumns** (), **removeRows** (),
        and **removeColumns** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QStringEncoder(QStringConverter):
    """
    https://doc.qt.io/qt-6/qstringencoder.html

    **Detailed Description**

    A text encoder converts text from Qt's internal representation into an
    encoded text format using a specific encoding.

    Converting a string from Unicode to the local encoding can be achieved using
    the following code:

    **QString**  string = "...";
        auto fromUtf16 =
    QStringEncoder(QStringEncoder::Utf8);
        **QByteArray**  encodedString =
    fromUtf16(string);

    The encoder remembers any state that is required between calls, so
    converting data received in chunks, for example, when receiving it over a
    network, is just as easy, by calling the encoder whenever new data is
    available:

    auto fromUtf16 = QStringEncoder(QStringEncoder::Utf8);
    **QByteArray**  encoded;
        while (new_data_available()) {
    **QString**  chunk = get_new_data();
            encoded += fromUtf16(chunk);
    }

    The QStringEncoder object maintains state between chunks and therefore works
    correctly even if a UTF-16 surrogate character is split between chunks.

    QStringEncoder objects can't be copied because of their internal state, but
    can be moved.

    **See also** **QStringConverter**  and **QStringDecoder** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstringencoder.html#QStringEncoder-1

        **QStringEncoder::QStringEncoder()**

        Default constructs an encoder. The default encoder is not valid, and
        can't be used for converting text.
        """
        ...

    @typing.overload
    def __init__(
        self,
        encoding: QStringConverter.Encoding,
        flags: QStringConverterBase.Flag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qstringencoder.html#QStringEncoder-2

        **QStringEncoder::QStringEncoder(QStringConverter::Encoding encoding ,
        QStringConverter::Flags flags = Flag::Default)**

        Creates an encoder object using **encoding** and **flags**.
        """
        ...

    @typing.overload
    def __init__(self, name: str, flags: QStringConverterBase.Flag = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstringencoder.html#QStringEncoder-3

        **QStringEncoder::QStringEncoder(const char * name ,
        QStringConverter::Flags flags = Flag::Default)**

        Creates an encoder object using **name** and **flags**. If **name** is
        not the name of a known encoding an invalid converter will get created.

        **See also** **isValid** ().
        """
        ...

    def encode(self, in_: str) -> QByteArray:
        ...

    def __call__(self, in_: str) -> QByteArray:
        ...
